/* Capstone Disassembly Engine, https://www.capstone-engine.org */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2022, */
/*    Rot127 <unisono@quyllur.org> 2022-2024 */
/* Automatically generated file by Capstone's LLVM TableGen Disassembler Backend. */

/* LLVM-commit: <commit> */
/* LLVM-tag: <tag> */

/* Do not edit. */

/* Capstone's LLVM TableGen Backends: */
/* https://github.com/capstone-engine/llvm-capstone */

#ifdef GET_INSTRINFO_ENUM
#undef GET_INSTRINFO_ENUM

  enum {
    TriCore_PHI	= 0,
    TriCore_INLINEASM	= 1,
    TriCore_INLINEASM_BR	= 2,
    TriCore_CFI_INSTRUCTION	= 3,
    TriCore_EH_LABEL	= 4,
    TriCore_GC_LABEL	= 5,
    TriCore_ANNOTATION_LABEL	= 6,
    TriCore_KILL	= 7,
    TriCore_EXTRACT_SUBREG	= 8,
    TriCore_INSERT_SUBREG	= 9,
    TriCore_IMPLICIT_DEF	= 10,
    TriCore_SUBREG_TO_REG	= 11,
    TriCore_COPY_TO_REGCLASS	= 12,
    TriCore_DBG_VALUE	= 13,
    TriCore_DBG_VALUE_LIST	= 14,
    TriCore_DBG_INSTR_REF	= 15,
    TriCore_DBG_PHI	= 16,
    TriCore_DBG_LABEL	= 17,
    TriCore_REG_SEQUENCE	= 18,
    TriCore_COPY	= 19,
    TriCore_BUNDLE	= 20,
    TriCore_LIFETIME_START	= 21,
    TriCore_LIFETIME_END	= 22,
    TriCore_PSEUDO_PROBE	= 23,
    TriCore_ARITH_FENCE	= 24,
    TriCore_STACKMAP	= 25,
    TriCore_FENTRY_CALL	= 26,
    TriCore_PATCHPOINT	= 27,
    TriCore_LOAD_STACK_GUARD	= 28,
    TriCore_PREALLOCATED_SETUP	= 29,
    TriCore_PREALLOCATED_ARG	= 30,
    TriCore_STATEPOINT	= 31,
    TriCore_LOCAL_ESCAPE	= 32,
    TriCore_FAULTING_OP	= 33,
    TriCore_PATCHABLE_OP	= 34,
    TriCore_PATCHABLE_FUNCTION_ENTER	= 35,
    TriCore_PATCHABLE_RET	= 36,
    TriCore_PATCHABLE_FUNCTION_EXIT	= 37,
    TriCore_PATCHABLE_TAIL_CALL	= 38,
    TriCore_PATCHABLE_EVENT_CALL	= 39,
    TriCore_PATCHABLE_TYPED_EVENT_CALL	= 40,
    TriCore_ICALL_BRANCH_FUNNEL	= 41,
    TriCore_MEMBARRIER	= 42,
    TriCore_JUMP_TABLE_DEBUG_INFO	= 43,
    TriCore_G_ASSERT_SEXT	= 44,
    TriCore_G_ASSERT_ZEXT	= 45,
    TriCore_G_ASSERT_ALIGN	= 46,
    TriCore_G_ADD	= 47,
    TriCore_G_SUB	= 48,
    TriCore_G_MUL	= 49,
    TriCore_G_SDIV	= 50,
    TriCore_G_UDIV	= 51,
    TriCore_G_SREM	= 52,
    TriCore_G_UREM	= 53,
    TriCore_G_SDIVREM	= 54,
    TriCore_G_UDIVREM	= 55,
    TriCore_G_AND	= 56,
    TriCore_G_OR	= 57,
    TriCore_G_XOR	= 58,
    TriCore_G_IMPLICIT_DEF	= 59,
    TriCore_G_PHI	= 60,
    TriCore_G_FRAME_INDEX	= 61,
    TriCore_G_GLOBAL_VALUE	= 62,
    TriCore_G_CONSTANT_POOL	= 63,
    TriCore_G_EXTRACT	= 64,
    TriCore_G_UNMERGE_VALUES	= 65,
    TriCore_G_INSERT	= 66,
    TriCore_G_MERGE_VALUES	= 67,
    TriCore_G_BUILD_VECTOR	= 68,
    TriCore_G_BUILD_VECTOR_TRUNC	= 69,
    TriCore_G_CONCAT_VECTORS	= 70,
    TriCore_G_PTRTOINT	= 71,
    TriCore_G_INTTOPTR	= 72,
    TriCore_G_BITCAST	= 73,
    TriCore_G_FREEZE	= 74,
    TriCore_G_CONSTANT_FOLD_BARRIER	= 75,
    TriCore_G_INTRINSIC_FPTRUNC_ROUND	= 76,
    TriCore_G_INTRINSIC_TRUNC	= 77,
    TriCore_G_INTRINSIC_ROUND	= 78,
    TriCore_G_INTRINSIC_LRINT	= 79,
    TriCore_G_INTRINSIC_ROUNDEVEN	= 80,
    TriCore_G_READCYCLECOUNTER	= 81,
    TriCore_G_LOAD	= 82,
    TriCore_G_SEXTLOAD	= 83,
    TriCore_G_ZEXTLOAD	= 84,
    TriCore_G_INDEXED_LOAD	= 85,
    TriCore_G_INDEXED_SEXTLOAD	= 86,
    TriCore_G_INDEXED_ZEXTLOAD	= 87,
    TriCore_G_STORE	= 88,
    TriCore_G_INDEXED_STORE	= 89,
    TriCore_G_ATOMIC_CMPXCHG_WITH_SUCCESS	= 90,
    TriCore_G_ATOMIC_CMPXCHG	= 91,
    TriCore_G_ATOMICRMW_XCHG	= 92,
    TriCore_G_ATOMICRMW_ADD	= 93,
    TriCore_G_ATOMICRMW_SUB	= 94,
    TriCore_G_ATOMICRMW_AND	= 95,
    TriCore_G_ATOMICRMW_NAND	= 96,
    TriCore_G_ATOMICRMW_OR	= 97,
    TriCore_G_ATOMICRMW_XOR	= 98,
    TriCore_G_ATOMICRMW_MAX	= 99,
    TriCore_G_ATOMICRMW_MIN	= 100,
    TriCore_G_ATOMICRMW_UMAX	= 101,
    TriCore_G_ATOMICRMW_UMIN	= 102,
    TriCore_G_ATOMICRMW_FADD	= 103,
    TriCore_G_ATOMICRMW_FSUB	= 104,
    TriCore_G_ATOMICRMW_FMAX	= 105,
    TriCore_G_ATOMICRMW_FMIN	= 106,
    TriCore_G_ATOMICRMW_UINC_WRAP	= 107,
    TriCore_G_ATOMICRMW_UDEC_WRAP	= 108,
    TriCore_G_FENCE	= 109,
    TriCore_G_PREFETCH	= 110,
    TriCore_G_BRCOND	= 111,
    TriCore_G_BRINDIRECT	= 112,
    TriCore_G_INVOKE_REGION_START	= 113,
    TriCore_G_INTRINSIC	= 114,
    TriCore_G_INTRINSIC_W_SIDE_EFFECTS	= 115,
    TriCore_G_INTRINSIC_CONVERGENT	= 116,
    TriCore_G_INTRINSIC_CONVERGENT_W_SIDE_EFFECTS	= 117,
    TriCore_G_ANYEXT	= 118,
    TriCore_G_TRUNC	= 119,
    TriCore_G_CONSTANT	= 120,
    TriCore_G_FCONSTANT	= 121,
    TriCore_G_VASTART	= 122,
    TriCore_G_VAARG	= 123,
    TriCore_G_SEXT	= 124,
    TriCore_G_SEXT_INREG	= 125,
    TriCore_G_ZEXT	= 126,
    TriCore_G_SHL	= 127,
    TriCore_G_LSHR	= 128,
    TriCore_G_ASHR	= 129,
    TriCore_G_FSHL	= 130,
    TriCore_G_FSHR	= 131,
    TriCore_G_ROTR	= 132,
    TriCore_G_ROTL	= 133,
    TriCore_G_ICMP	= 134,
    TriCore_G_FCMP	= 135,
    TriCore_G_SELECT	= 136,
    TriCore_G_UADDO	= 137,
    TriCore_G_UADDE	= 138,
    TriCore_G_USUBO	= 139,
    TriCore_G_USUBE	= 140,
    TriCore_G_SADDO	= 141,
    TriCore_G_SADDE	= 142,
    TriCore_G_SSUBO	= 143,
    TriCore_G_SSUBE	= 144,
    TriCore_G_UMULO	= 145,
    TriCore_G_SMULO	= 146,
    TriCore_G_UMULH	= 147,
    TriCore_G_SMULH	= 148,
    TriCore_G_UADDSAT	= 149,
    TriCore_G_SADDSAT	= 150,
    TriCore_G_USUBSAT	= 151,
    TriCore_G_SSUBSAT	= 152,
    TriCore_G_USHLSAT	= 153,
    TriCore_G_SSHLSAT	= 154,
    TriCore_G_SMULFIX	= 155,
    TriCore_G_UMULFIX	= 156,
    TriCore_G_SMULFIXSAT	= 157,
    TriCore_G_UMULFIXSAT	= 158,
    TriCore_G_SDIVFIX	= 159,
    TriCore_G_UDIVFIX	= 160,
    TriCore_G_SDIVFIXSAT	= 161,
    TriCore_G_UDIVFIXSAT	= 162,
    TriCore_G_FADD	= 163,
    TriCore_G_FSUB	= 164,
    TriCore_G_FMUL	= 165,
    TriCore_G_FMA	= 166,
    TriCore_G_FMAD	= 167,
    TriCore_G_FDIV	= 168,
    TriCore_G_FREM	= 169,
    TriCore_G_FPOW	= 170,
    TriCore_G_FPOWI	= 171,
    TriCore_G_FEXP	= 172,
    TriCore_G_FEXP2	= 173,
    TriCore_G_FEXP10	= 174,
    TriCore_G_FLOG	= 175,
    TriCore_G_FLOG2	= 176,
    TriCore_G_FLOG10	= 177,
    TriCore_G_FLDEXP	= 178,
    TriCore_G_FFREXP	= 179,
    TriCore_G_FNEG	= 180,
    TriCore_G_FPEXT	= 181,
    TriCore_G_FPTRUNC	= 182,
    TriCore_G_FPTOSI	= 183,
    TriCore_G_FPTOUI	= 184,
    TriCore_G_SITOFP	= 185,
    TriCore_G_UITOFP	= 186,
    TriCore_G_FABS	= 187,
    TriCore_G_FCOPYSIGN	= 188,
    TriCore_G_IS_FPCLASS	= 189,
    TriCore_G_FCANONICALIZE	= 190,
    TriCore_G_FMINNUM	= 191,
    TriCore_G_FMAXNUM	= 192,
    TriCore_G_FMINNUM_IEEE	= 193,
    TriCore_G_FMAXNUM_IEEE	= 194,
    TriCore_G_FMINIMUM	= 195,
    TriCore_G_FMAXIMUM	= 196,
    TriCore_G_GET_FPENV	= 197,
    TriCore_G_SET_FPENV	= 198,
    TriCore_G_RESET_FPENV	= 199,
    TriCore_G_GET_FPMODE	= 200,
    TriCore_G_SET_FPMODE	= 201,
    TriCore_G_RESET_FPMODE	= 202,
    TriCore_G_PTR_ADD	= 203,
    TriCore_G_PTRMASK	= 204,
    TriCore_G_SMIN	= 205,
    TriCore_G_SMAX	= 206,
    TriCore_G_UMIN	= 207,
    TriCore_G_UMAX	= 208,
    TriCore_G_ABS	= 209,
    TriCore_G_LROUND	= 210,
    TriCore_G_LLROUND	= 211,
    TriCore_G_BR	= 212,
    TriCore_G_BRJT	= 213,
    TriCore_G_INSERT_VECTOR_ELT	= 214,
    TriCore_G_EXTRACT_VECTOR_ELT	= 215,
    TriCore_G_SHUFFLE_VECTOR	= 216,
    TriCore_G_CTTZ	= 217,
    TriCore_G_CTTZ_ZERO_UNDEF	= 218,
    TriCore_G_CTLZ	= 219,
    TriCore_G_CTLZ_ZERO_UNDEF	= 220,
    TriCore_G_CTPOP	= 221,
    TriCore_G_BSWAP	= 222,
    TriCore_G_BITREVERSE	= 223,
    TriCore_G_FCEIL	= 224,
    TriCore_G_FCOS	= 225,
    TriCore_G_FSIN	= 226,
    TriCore_G_FSQRT	= 227,
    TriCore_G_FFLOOR	= 228,
    TriCore_G_FRINT	= 229,
    TriCore_G_FNEARBYINT	= 230,
    TriCore_G_ADDRSPACE_CAST	= 231,
    TriCore_G_BLOCK_ADDR	= 232,
    TriCore_G_JUMP_TABLE	= 233,
    TriCore_G_DYN_STACKALLOC	= 234,
    TriCore_G_STACKSAVE	= 235,
    TriCore_G_STACKRESTORE	= 236,
    TriCore_G_STRICT_FADD	= 237,
    TriCore_G_STRICT_FSUB	= 238,
    TriCore_G_STRICT_FMUL	= 239,
    TriCore_G_STRICT_FDIV	= 240,
    TriCore_G_STRICT_FREM	= 241,
    TriCore_G_STRICT_FMA	= 242,
    TriCore_G_STRICT_FSQRT	= 243,
    TriCore_G_STRICT_FLDEXP	= 244,
    TriCore_G_READ_REGISTER	= 245,
    TriCore_G_WRITE_REGISTER	= 246,
    TriCore_G_MEMCPY	= 247,
    TriCore_G_MEMCPY_INLINE	= 248,
    TriCore_G_MEMMOVE	= 249,
    TriCore_G_MEMSET	= 250,
    TriCore_G_BZERO	= 251,
    TriCore_G_VECREDUCE_SEQ_FADD	= 252,
    TriCore_G_VECREDUCE_SEQ_FMUL	= 253,
    TriCore_G_VECREDUCE_FADD	= 254,
    TriCore_G_VECREDUCE_FMUL	= 255,
    TriCore_G_VECREDUCE_FMAX	= 256,
    TriCore_G_VECREDUCE_FMIN	= 257,
    TriCore_G_VECREDUCE_FMAXIMUM	= 258,
    TriCore_G_VECREDUCE_FMINIMUM	= 259,
    TriCore_G_VECREDUCE_ADD	= 260,
    TriCore_G_VECREDUCE_MUL	= 261,
    TriCore_G_VECREDUCE_AND	= 262,
    TriCore_G_VECREDUCE_OR	= 263,
    TriCore_G_VECREDUCE_XOR	= 264,
    TriCore_G_VECREDUCE_SMAX	= 265,
    TriCore_G_VECREDUCE_SMIN	= 266,
    TriCore_G_VECREDUCE_UMAX	= 267,
    TriCore_G_VECREDUCE_UMIN	= 268,
    TriCore_G_SBFX	= 269,
    TriCore_G_UBFX	= 270,
    TriCore_ABSDIFS_B_rr_v110	= 271,
    TriCore_ABSDIFS_H_rr	= 272,
    TriCore_ABSDIFS_rc	= 273,
    TriCore_ABSDIFS_rr	= 274,
    TriCore_ABSDIF_B_rr	= 275,
    TriCore_ABSDIF_H_rr	= 276,
    TriCore_ABSDIF_rc	= 277,
    TriCore_ABSDIF_rr	= 278,
    TriCore_ABSS_B_rr_v110	= 279,
    TriCore_ABSS_H_rr	= 280,
    TriCore_ABSS_rr	= 281,
    TriCore_ABS_B_rr	= 282,
    TriCore_ABS_DF_rr	= 283,
    TriCore_ABS_F_rr	= 284,
    TriCore_ABS_H_rr	= 285,
    TriCore_ABS_rr	= 286,
    TriCore_ADDC_rc	= 287,
    TriCore_ADDC_rr	= 288,
    TriCore_ADDIH_A_rlc	= 289,
    TriCore_ADDIH_rlc	= 290,
    TriCore_ADDI_rlc	= 291,
    TriCore_ADDSC_AT_rr	= 292,
    TriCore_ADDSC_AT_rr_v110	= 293,
    TriCore_ADDSC_A_rr	= 294,
    TriCore_ADDSC_A_rr_v110	= 295,
    TriCore_ADDSC_A_srrs	= 296,
    TriCore_ADDSC_A_srrs_v110	= 297,
    TriCore_ADDS_BU_rr_v110	= 298,
    TriCore_ADDS_B_rr	= 299,
    TriCore_ADDS_H	= 300,
    TriCore_ADDS_HU	= 301,
    TriCore_ADDS_U	= 302,
    TriCore_ADDS_U_rc	= 303,
    TriCore_ADDS_rc	= 304,
    TriCore_ADDS_rr	= 305,
    TriCore_ADDS_srr	= 306,
    TriCore_ADDX_rc	= 307,
    TriCore_ADDX_rr	= 308,
    TriCore_ADD_A_rr	= 309,
    TriCore_ADD_A_src	= 310,
    TriCore_ADD_A_srr	= 311,
    TriCore_ADD_B_rr	= 312,
    TriCore_ADD_DF_rrr	= 313,
    TriCore_ADD_F_rrr	= 314,
    TriCore_ADD_H_rr	= 315,
    TriCore_ADD_rc	= 316,
    TriCore_ADD_rr	= 317,
    TriCore_ADD_src	= 318,
    TriCore_ADD_src_15a	= 319,
    TriCore_ADD_src_a15	= 320,
    TriCore_ADD_srr	= 321,
    TriCore_ADD_srr_15a	= 322,
    TriCore_ADD_srr_a15	= 323,
    TriCore_ANDN_T	= 324,
    TriCore_ANDN_rc	= 325,
    TriCore_ANDN_rr	= 326,
    TriCore_AND_ANDN_T	= 327,
    TriCore_AND_AND_T	= 328,
    TriCore_AND_EQ_rc	= 329,
    TriCore_AND_EQ_rr	= 330,
    TriCore_AND_GE_U_rc	= 331,
    TriCore_AND_GE_U_rr	= 332,
    TriCore_AND_GE_rc	= 333,
    TriCore_AND_GE_rr	= 334,
    TriCore_AND_LT_U_rc	= 335,
    TriCore_AND_LT_U_rr	= 336,
    TriCore_AND_LT_rc	= 337,
    TriCore_AND_LT_rr	= 338,
    TriCore_AND_NE_rc	= 339,
    TriCore_AND_NE_rr	= 340,
    TriCore_AND_NOR_T	= 341,
    TriCore_AND_OR_T	= 342,
    TriCore_AND_T	= 343,
    TriCore_AND_rc	= 344,
    TriCore_AND_rr	= 345,
    TriCore_AND_sc	= 346,
    TriCore_AND_sc_v110	= 347,
    TriCore_AND_srr	= 348,
    TriCore_AND_srr_v110	= 349,
    TriCore_BISR_rc	= 350,
    TriCore_BISR_sc	= 351,
    TriCore_BISR_sc_v110	= 352,
    TriCore_BMERGAE_rr_v110	= 353,
    TriCore_BMERGE_rr	= 354,
    TriCore_BSPLIT_rr	= 355,
    TriCore_BSPLIT_rr_v110	= 356,
    TriCore_CACHEA_I_bo_bso	= 357,
    TriCore_CACHEA_I_bo_c	= 358,
    TriCore_CACHEA_I_bo_pos	= 359,
    TriCore_CACHEA_I_bo_pre	= 360,
    TriCore_CACHEA_I_bo_r	= 361,
    TriCore_CACHEA_WI_bo_bso	= 362,
    TriCore_CACHEA_WI_bo_c	= 363,
    TriCore_CACHEA_WI_bo_pos	= 364,
    TriCore_CACHEA_WI_bo_pre	= 365,
    TriCore_CACHEA_WI_bo_r	= 366,
    TriCore_CACHEA_W_bo_bso	= 367,
    TriCore_CACHEA_W_bo_c	= 368,
    TriCore_CACHEA_W_bo_pos	= 369,
    TriCore_CACHEA_W_bo_pre	= 370,
    TriCore_CACHEA_W_bo_r	= 371,
    TriCore_CACHEI_I_bo_bso	= 372,
    TriCore_CACHEI_I_bo_pos	= 373,
    TriCore_CACHEI_I_bo_pre	= 374,
    TriCore_CACHEI_WI_bo_bso	= 375,
    TriCore_CACHEI_WI_bo_pos	= 376,
    TriCore_CACHEI_WI_bo_pre	= 377,
    TriCore_CACHEI_W_bo_bso	= 378,
    TriCore_CACHEI_W_bo_pos	= 379,
    TriCore_CACHEI_W_bo_pre	= 380,
    TriCore_CADDN_A_rcr_v110	= 381,
    TriCore_CADDN_A_rrr_v110	= 382,
    TriCore_CADDN_rcr	= 383,
    TriCore_CADDN_rrr	= 384,
    TriCore_CADDN_src	= 385,
    TriCore_CADDN_srr_v110	= 386,
    TriCore_CADD_A_rcr_v110	= 387,
    TriCore_CADD_A_rrr_v110	= 388,
    TriCore_CADD_rcr	= 389,
    TriCore_CADD_rrr	= 390,
    TriCore_CADD_src	= 391,
    TriCore_CADD_srr_v110	= 392,
    TriCore_CALLA_b	= 393,
    TriCore_CALLI_rr	= 394,
    TriCore_CALLI_rr_v110	= 395,
    TriCore_CALL_b	= 396,
    TriCore_CALL_sb	= 397,
    TriCore_CLO_B_rr_v110	= 398,
    TriCore_CLO_H_rr	= 399,
    TriCore_CLO_rr	= 400,
    TriCore_CLS_B_rr_v110	= 401,
    TriCore_CLS_H_rr	= 402,
    TriCore_CLS_rr	= 403,
    TriCore_CLZ_B_rr_v110	= 404,
    TriCore_CLZ_H_rr	= 405,
    TriCore_CLZ_rr	= 406,
    TriCore_CMOVN_src	= 407,
    TriCore_CMOVN_srr	= 408,
    TriCore_CMOV_src	= 409,
    TriCore_CMOV_srr	= 410,
    TriCore_CMPSWAP_W_bo_bso	= 411,
    TriCore_CMPSWAP_W_bo_c	= 412,
    TriCore_CMPSWAP_W_bo_pos	= 413,
    TriCore_CMPSWAP_W_bo_pre	= 414,
    TriCore_CMPSWAP_W_bo_r	= 415,
    TriCore_CMP_DF_rr	= 416,
    TriCore_CMP_F_rr	= 417,
    TriCore_CRC32B_W_rr	= 418,
    TriCore_CRC32L_W_rr	= 419,
    TriCore_CRC32_B_rr	= 420,
    TriCore_CRCN_rrr	= 421,
    TriCore_CSUBN_A__rrr_v110	= 422,
    TriCore_CSUBN_rrr	= 423,
    TriCore_CSUB_A__rrr_v110	= 424,
    TriCore_CSUB_rrr	= 425,
    TriCore_DEBUG_sr	= 426,
    TriCore_DEBUG_sys	= 427,
    TriCore_DEXTR_rrpw	= 428,
    TriCore_DEXTR_rrrr	= 429,
    TriCore_DFTOF_rr	= 430,
    TriCore_DFTOIN_rr	= 431,
    TriCore_DFTOIZ_rr	= 432,
    TriCore_DFTOI_rr	= 433,
    TriCore_DFTOLZ_rr	= 434,
    TriCore_DFTOL_rr	= 435,
    TriCore_DFTOULZ_rr	= 436,
    TriCore_DFTOUL_rr	= 437,
    TriCore_DFTOUZ_rr	= 438,
    TriCore_DFTOU_rr	= 439,
    TriCore_DIFSC_A_rr_v110	= 440,
    TriCore_DISABLE_sys	= 441,
    TriCore_DISABLE_sys_1	= 442,
    TriCore_DIV64_U_rr	= 443,
    TriCore_DIV64_rr	= 444,
    TriCore_DIV_DF_rr	= 445,
    TriCore_DIV_F_rr	= 446,
    TriCore_DIV_U_rr	= 447,
    TriCore_DIV_rr	= 448,
    TriCore_DSYNC_sys	= 449,
    TriCore_DVADJ_rrr	= 450,
    TriCore_DVADJ_rrr_v110	= 451,
    TriCore_DVADJ_srr_v110	= 452,
    TriCore_DVINIT_BU_rr	= 453,
    TriCore_DVINIT_BU_rr_v110	= 454,
    TriCore_DVINIT_B_rr	= 455,
    TriCore_DVINIT_B_rr_v110	= 456,
    TriCore_DVINIT_HU_rr	= 457,
    TriCore_DVINIT_HU_rr_v110	= 458,
    TriCore_DVINIT_H_rr	= 459,
    TriCore_DVINIT_H_rr_v110	= 460,
    TriCore_DVINIT_U_rr	= 461,
    TriCore_DVINIT_U_rr_v110	= 462,
    TriCore_DVINIT_rr	= 463,
    TriCore_DVINIT_rr_v110	= 464,
    TriCore_DVSTEP_U_rrr	= 465,
    TriCore_DVSTEP_U_rrrv110	= 466,
    TriCore_DVSTEP_Uv110	= 467,
    TriCore_DVSTEP_rrr	= 468,
    TriCore_DVSTEP_rrrv110	= 469,
    TriCore_DVSTEPv110	= 470,
    TriCore_ENABLE_sys	= 471,
    TriCore_EQANY_B_rc	= 472,
    TriCore_EQANY_B_rr	= 473,
    TriCore_EQANY_H_rc	= 474,
    TriCore_EQANY_H_rr	= 475,
    TriCore_EQZ_A_rr	= 476,
    TriCore_EQ_A_rr	= 477,
    TriCore_EQ_B_rr	= 478,
    TriCore_EQ_H_rr	= 479,
    TriCore_EQ_W_rr	= 480,
    TriCore_EQ_rc	= 481,
    TriCore_EQ_rr	= 482,
    TriCore_EQ_src	= 483,
    TriCore_EQ_srr	= 484,
    TriCore_EXTR_U_rrpw	= 485,
    TriCore_EXTR_U_rrrr	= 486,
    TriCore_EXTR_U_rrrw	= 487,
    TriCore_EXTR_rrpw	= 488,
    TriCore_EXTR_rrrr	= 489,
    TriCore_EXTR_rrrw	= 490,
    TriCore_FCALLA_b	= 491,
    TriCore_FCALLA_i	= 492,
    TriCore_FCALL_b	= 493,
    TriCore_FRET_sr	= 494,
    TriCore_FRET_sys	= 495,
    TriCore_FTODF_rr	= 496,
    TriCore_FTOHP_rr	= 497,
    TriCore_FTOIN_rr	= 498,
    TriCore_FTOIZ_rr	= 499,
    TriCore_FTOI_rr	= 500,
    TriCore_FTOQ31Z_rr	= 501,
    TriCore_FTOQ31_rr	= 502,
    TriCore_FTOUZ_rr	= 503,
    TriCore_FTOU_rr	= 504,
    TriCore_GE_A_rr	= 505,
    TriCore_GE_U_rc	= 506,
    TriCore_GE_U_rr	= 507,
    TriCore_GE_rc	= 508,
    TriCore_GE_rr	= 509,
    TriCore_HPTOF_rr	= 510,
    TriCore_IMASK_rcpw	= 511,
    TriCore_IMASK_rcrw	= 512,
    TriCore_IMASK_rrpw	= 513,
    TriCore_IMASK_rrrw	= 514,
    TriCore_INSERT_rcpw	= 515,
    TriCore_INSERT_rcrr	= 516,
    TriCore_INSERT_rcrw	= 517,
    TriCore_INSERT_rrpw	= 518,
    TriCore_INSERT_rrrr	= 519,
    TriCore_INSERT_rrrw	= 520,
    TriCore_INSN_T	= 521,
    TriCore_INS_T	= 522,
    TriCore_ISYNC_sys	= 523,
    TriCore_ITODF_rr	= 524,
    TriCore_ITOF_rr	= 525,
    TriCore_IXMAX_U_rrr	= 526,
    TriCore_IXMAX_rrr	= 527,
    TriCore_IXMIN_U_rrr	= 528,
    TriCore_IXMIN_rrr	= 529,
    TriCore_JA_b	= 530,
    TriCore_JEQ_A_brr	= 531,
    TriCore_JEQ_brc	= 532,
    TriCore_JEQ_brr	= 533,
    TriCore_JEQ_sbc1	= 534,
    TriCore_JEQ_sbc2	= 535,
    TriCore_JEQ_sbc_v110	= 536,
    TriCore_JEQ_sbr1	= 537,
    TriCore_JEQ_sbr2	= 538,
    TriCore_JEQ_sbr_v110	= 539,
    TriCore_JGEZ_sbr	= 540,
    TriCore_JGEZ_sbr_v110	= 541,
    TriCore_JGE_U_brc	= 542,
    TriCore_JGE_U_brr	= 543,
    TriCore_JGE_brc	= 544,
    TriCore_JGE_brr	= 545,
    TriCore_JGTZ_sbr	= 546,
    TriCore_JGTZ_sbr_v110	= 547,
    TriCore_JI_rr	= 548,
    TriCore_JI_rr_v110	= 549,
    TriCore_JI_sbr_v110	= 550,
    TriCore_JI_sr	= 551,
    TriCore_JLA_b	= 552,
    TriCore_JLEZ_sbr	= 553,
    TriCore_JLEZ_sbr_v110	= 554,
    TriCore_JLI_rr	= 555,
    TriCore_JLI_rr_v110	= 556,
    TriCore_JLTZ_sbr	= 557,
    TriCore_JLTZ_sbr_v110	= 558,
    TriCore_JLT_U_brc	= 559,
    TriCore_JLT_U_brr	= 560,
    TriCore_JLT_brc	= 561,
    TriCore_JLT_brr	= 562,
    TriCore_JL_b	= 563,
    TriCore_JNED_brc	= 564,
    TriCore_JNED_brr	= 565,
    TriCore_JNEI_brc	= 566,
    TriCore_JNEI_brr	= 567,
    TriCore_JNE_A_brr	= 568,
    TriCore_JNE_brc	= 569,
    TriCore_JNE_brr	= 570,
    TriCore_JNE_sbc1	= 571,
    TriCore_JNE_sbc2	= 572,
    TriCore_JNE_sbc_v110	= 573,
    TriCore_JNE_sbr1	= 574,
    TriCore_JNE_sbr2	= 575,
    TriCore_JNE_sbr_v110	= 576,
    TriCore_JNZ_A_brr	= 577,
    TriCore_JNZ_A_sbr	= 578,
    TriCore_JNZ_T_brn	= 579,
    TriCore_JNZ_T_sbrn	= 580,
    TriCore_JNZ_T_sbrn_v110	= 581,
    TriCore_JNZ_sb	= 582,
    TriCore_JNZ_sb_v110	= 583,
    TriCore_JNZ_sbr	= 584,
    TriCore_JNZ_sbr_v110	= 585,
    TriCore_JZ_A_brr	= 586,
    TriCore_JZ_A_sbr	= 587,
    TriCore_JZ_T_brn	= 588,
    TriCore_JZ_T_sbrn	= 589,
    TriCore_JZ_T_sbrn_v110	= 590,
    TriCore_JZ_sb	= 591,
    TriCore_JZ_sb_v110	= 592,
    TriCore_JZ_sbr	= 593,
    TriCore_JZ_sbr_v110	= 594,
    TriCore_J_b	= 595,
    TriCore_J_sb	= 596,
    TriCore_J_sb_v110	= 597,
    TriCore_LDLCX_abs	= 598,
    TriCore_LDLCX_bo_bso	= 599,
    TriCore_LDMST_abs	= 600,
    TriCore_LDMST_bo_bso	= 601,
    TriCore_LDMST_bo_c	= 602,
    TriCore_LDMST_bo_pos	= 603,
    TriCore_LDMST_bo_pre	= 604,
    TriCore_LDMST_bo_r	= 605,
    TriCore_LDUCX_abs	= 606,
    TriCore_LDUCX_bo_bso	= 607,
    TriCore_LD_A_abs	= 608,
    TriCore_LD_A_bo_bso	= 609,
    TriCore_LD_A_bo_c	= 610,
    TriCore_LD_A_bo_pos	= 611,
    TriCore_LD_A_bo_pre	= 612,
    TriCore_LD_A_bo_r	= 613,
    TriCore_LD_A_bol	= 614,
    TriCore_LD_A_sc	= 615,
    TriCore_LD_A_slr	= 616,
    TriCore_LD_A_slr_post	= 617,
    TriCore_LD_A_slr_post_v110	= 618,
    TriCore_LD_A_slr_v110	= 619,
    TriCore_LD_A_slro	= 620,
    TriCore_LD_A_slro_v110	= 621,
    TriCore_LD_A_sro	= 622,
    TriCore_LD_A_sro_v110	= 623,
    TriCore_LD_BU_abs	= 624,
    TriCore_LD_BU_bo_bso	= 625,
    TriCore_LD_BU_bo_c	= 626,
    TriCore_LD_BU_bo_pos	= 627,
    TriCore_LD_BU_bo_pre	= 628,
    TriCore_LD_BU_bo_r	= 629,
    TriCore_LD_BU_bol	= 630,
    TriCore_LD_BU_slr	= 631,
    TriCore_LD_BU_slr_post	= 632,
    TriCore_LD_BU_slr_post_v110	= 633,
    TriCore_LD_BU_slr_v110	= 634,
    TriCore_LD_BU_slro	= 635,
    TriCore_LD_BU_slro_v110	= 636,
    TriCore_LD_BU_sro	= 637,
    TriCore_LD_BU_sro_v110	= 638,
    TriCore_LD_B_abs	= 639,
    TriCore_LD_B_bo_bso	= 640,
    TriCore_LD_B_bo_c	= 641,
    TriCore_LD_B_bo_pos	= 642,
    TriCore_LD_B_bo_pre	= 643,
    TriCore_LD_B_bo_r	= 644,
    TriCore_LD_B_bol	= 645,
    TriCore_LD_B_slr_post_v110	= 646,
    TriCore_LD_B_slr_v110	= 647,
    TriCore_LD_B_slro_v110	= 648,
    TriCore_LD_B_sro_v110	= 649,
    TriCore_LD_DA_abs	= 650,
    TriCore_LD_DA_bo_bso	= 651,
    TriCore_LD_DA_bo_c	= 652,
    TriCore_LD_DA_bo_pos	= 653,
    TriCore_LD_DA_bo_pre	= 654,
    TriCore_LD_DA_bo_r	= 655,
    TriCore_LD_D_abs	= 656,
    TriCore_LD_D_bo_bso	= 657,
    TriCore_LD_D_bo_c	= 658,
    TriCore_LD_D_bo_pos	= 659,
    TriCore_LD_D_bo_pre	= 660,
    TriCore_LD_D_bo_r	= 661,
    TriCore_LD_HU_abs	= 662,
    TriCore_LD_HU_bo_bso	= 663,
    TriCore_LD_HU_bo_c	= 664,
    TriCore_LD_HU_bo_pos	= 665,
    TriCore_LD_HU_bo_pre	= 666,
    TriCore_LD_HU_bo_r	= 667,
    TriCore_LD_HU_bol	= 668,
    TriCore_LD_H_abs	= 669,
    TriCore_LD_H_bo_bso	= 670,
    TriCore_LD_H_bo_c	= 671,
    TriCore_LD_H_bo_pos	= 672,
    TriCore_LD_H_bo_pre	= 673,
    TriCore_LD_H_bo_r	= 674,
    TriCore_LD_H_bol	= 675,
    TriCore_LD_H_slr	= 676,
    TriCore_LD_H_slr_post	= 677,
    TriCore_LD_H_slr_post_v110	= 678,
    TriCore_LD_H_slr_v110	= 679,
    TriCore_LD_H_slro	= 680,
    TriCore_LD_H_slro_v110	= 681,
    TriCore_LD_H_sro	= 682,
    TriCore_LD_H_sro_v110	= 683,
    TriCore_LD_Q_abs	= 684,
    TriCore_LD_Q_bo_bso	= 685,
    TriCore_LD_Q_bo_c	= 686,
    TriCore_LD_Q_bo_pos	= 687,
    TriCore_LD_Q_bo_pre	= 688,
    TriCore_LD_Q_bo_r	= 689,
    TriCore_LD_W_abs	= 690,
    TriCore_LD_W_bo_bso	= 691,
    TriCore_LD_W_bo_c	= 692,
    TriCore_LD_W_bo_pos	= 693,
    TriCore_LD_W_bo_pre	= 694,
    TriCore_LD_W_bo_r	= 695,
    TriCore_LD_W_bol	= 696,
    TriCore_LD_W_sc	= 697,
    TriCore_LD_W_slr	= 698,
    TriCore_LD_W_slr_post	= 699,
    TriCore_LD_W_slr_post_v110	= 700,
    TriCore_LD_W_slr_v110	= 701,
    TriCore_LD_W_slro	= 702,
    TriCore_LD_W_slro_v110	= 703,
    TriCore_LD_W_sro	= 704,
    TriCore_LD_W_sro_v110	= 705,
    TriCore_LEA_abs	= 706,
    TriCore_LEA_bo_bso	= 707,
    TriCore_LEA_bol	= 708,
    TriCore_LHA_abs	= 709,
    TriCore_LOOPU_brr	= 710,
    TriCore_LOOP_brr	= 711,
    TriCore_LOOP_sbr	= 712,
    TriCore_LTODF_rr	= 713,
    TriCore_LT_A_rr	= 714,
    TriCore_LT_B	= 715,
    TriCore_LT_BU	= 716,
    TriCore_LT_H	= 717,
    TriCore_LT_HU	= 718,
    TriCore_LT_U_rc	= 719,
    TriCore_LT_U_rr	= 720,
    TriCore_LT_U_srcv110	= 721,
    TriCore_LT_U_srrv110	= 722,
    TriCore_LT_W	= 723,
    TriCore_LT_WU	= 724,
    TriCore_LT_rc	= 725,
    TriCore_LT_rr	= 726,
    TriCore_LT_src	= 727,
    TriCore_LT_srr	= 728,
    TriCore_MADDMS_H_rrr1_LL	= 729,
    TriCore_MADDMS_H_rrr1_LU	= 730,
    TriCore_MADDMS_H_rrr1_UL	= 731,
    TriCore_MADDMS_H_rrr1_UU	= 732,
    TriCore_MADDMS_U_rcr_v110	= 733,
    TriCore_MADDMS_U_rrr2_v110	= 734,
    TriCore_MADDMS_rcr_v110	= 735,
    TriCore_MADDMS_rrr2_v110	= 736,
    TriCore_MADDM_H_rrr1_LL	= 737,
    TriCore_MADDM_H_rrr1_LU	= 738,
    TriCore_MADDM_H_rrr1_UL	= 739,
    TriCore_MADDM_H_rrr1_UU	= 740,
    TriCore_MADDM_H_rrr1_v110	= 741,
    TriCore_MADDM_Q_rrr1_v110	= 742,
    TriCore_MADDM_U_rcr_v110	= 743,
    TriCore_MADDM_U_rrr2_v110	= 744,
    TriCore_MADDM_rcr_v110	= 745,
    TriCore_MADDM_rrr2_v110	= 746,
    TriCore_MADDRS_H_rrr1_LL	= 747,
    TriCore_MADDRS_H_rrr1_LU	= 748,
    TriCore_MADDRS_H_rrr1_UL	= 749,
    TriCore_MADDRS_H_rrr1_UL_2	= 750,
    TriCore_MADDRS_H_rrr1_UU	= 751,
    TriCore_MADDRS_H_rrr1_v110	= 752,
    TriCore_MADDRS_Q_rrr1_L_L	= 753,
    TriCore_MADDRS_Q_rrr1_U_U	= 754,
    TriCore_MADDRS_Q_rrr1_v110	= 755,
    TriCore_MADDR_H_rrr1_LL	= 756,
    TriCore_MADDR_H_rrr1_LU	= 757,
    TriCore_MADDR_H_rrr1_UL	= 758,
    TriCore_MADDR_H_rrr1_UL_2	= 759,
    TriCore_MADDR_H_rrr1_UU	= 760,
    TriCore_MADDR_H_rrr1_v110	= 761,
    TriCore_MADDR_Q_rrr1_L_L	= 762,
    TriCore_MADDR_Q_rrr1_U_U	= 763,
    TriCore_MADDR_Q_rrr1_v110	= 764,
    TriCore_MADDSUMS_H_rrr1_LL	= 765,
    TriCore_MADDSUMS_H_rrr1_LU	= 766,
    TriCore_MADDSUMS_H_rrr1_UL	= 767,
    TriCore_MADDSUMS_H_rrr1_UU	= 768,
    TriCore_MADDSUM_H_rrr1_LL	= 769,
    TriCore_MADDSUM_H_rrr1_LU	= 770,
    TriCore_MADDSUM_H_rrr1_UL	= 771,
    TriCore_MADDSUM_H_rrr1_UU	= 772,
    TriCore_MADDSURS_H_rrr1_LL	= 773,
    TriCore_MADDSURS_H_rrr1_LU	= 774,
    TriCore_MADDSURS_H_rrr1_UL	= 775,
    TriCore_MADDSURS_H_rrr1_UU	= 776,
    TriCore_MADDSUR_H_rrr1_LL	= 777,
    TriCore_MADDSUR_H_rrr1_LU	= 778,
    TriCore_MADDSUR_H_rrr1_UL	= 779,
    TriCore_MADDSUR_H_rrr1_UU	= 780,
    TriCore_MADDSUS_H_rrr1_LL	= 781,
    TriCore_MADDSUS_H_rrr1_LU	= 782,
    TriCore_MADDSUS_H_rrr1_UL	= 783,
    TriCore_MADDSUS_H_rrr1_UU	= 784,
    TriCore_MADDSU_H_rrr1_LL	= 785,
    TriCore_MADDSU_H_rrr1_LU	= 786,
    TriCore_MADDSU_H_rrr1_UL	= 787,
    TriCore_MADDSU_H_rrr1_UU	= 788,
    TriCore_MADDS_H_rrr1_LL	= 789,
    TriCore_MADDS_H_rrr1_LU	= 790,
    TriCore_MADDS_H_rrr1_UL	= 791,
    TriCore_MADDS_H_rrr1_UU	= 792,
    TriCore_MADDS_H_rrr1_v110	= 793,
    TriCore_MADDS_Q_rrr1	= 794,
    TriCore_MADDS_Q_rrr1_L	= 795,
    TriCore_MADDS_Q_rrr1_L_L	= 796,
    TriCore_MADDS_Q_rrr1_U	= 797,
    TriCore_MADDS_Q_rrr1_UU2_v110	= 798,
    TriCore_MADDS_Q_rrr1_U_U	= 799,
    TriCore_MADDS_Q_rrr1_e	= 800,
    TriCore_MADDS_Q_rrr1_e_L	= 801,
    TriCore_MADDS_Q_rrr1_e_L_L	= 802,
    TriCore_MADDS_Q_rrr1_e_U	= 803,
    TriCore_MADDS_Q_rrr1_e_U_U	= 804,
    TriCore_MADDS_U_rcr	= 805,
    TriCore_MADDS_U_rcr_e	= 806,
    TriCore_MADDS_U_rrr2	= 807,
    TriCore_MADDS_U_rrr2_e	= 808,
    TriCore_MADDS_rcr	= 809,
    TriCore_MADDS_rcr_e	= 810,
    TriCore_MADDS_rrr2	= 811,
    TriCore_MADDS_rrr2_e	= 812,
    TriCore_MADD_DF_rrr	= 813,
    TriCore_MADD_F_rrr	= 814,
    TriCore_MADD_H_rrr1_LL	= 815,
    TriCore_MADD_H_rrr1_LU	= 816,
    TriCore_MADD_H_rrr1_UL	= 817,
    TriCore_MADD_H_rrr1_UU	= 818,
    TriCore_MADD_H_rrr1_v110	= 819,
    TriCore_MADD_Q_rrr1	= 820,
    TriCore_MADD_Q_rrr1_L	= 821,
    TriCore_MADD_Q_rrr1_L_L	= 822,
    TriCore_MADD_Q_rrr1_U	= 823,
    TriCore_MADD_Q_rrr1_UU2_v110	= 824,
    TriCore_MADD_Q_rrr1_U_U	= 825,
    TriCore_MADD_Q_rrr1_e	= 826,
    TriCore_MADD_Q_rrr1_e_L	= 827,
    TriCore_MADD_Q_rrr1_e_L_L	= 828,
    TriCore_MADD_Q_rrr1_e_U	= 829,
    TriCore_MADD_Q_rrr1_e_U_U	= 830,
    TriCore_MADD_U_rcr	= 831,
    TriCore_MADD_U_rrr2	= 832,
    TriCore_MADD_rcr	= 833,
    TriCore_MADD_rcr_e	= 834,
    TriCore_MADD_rrr2	= 835,
    TriCore_MADD_rrr2_e	= 836,
    TriCore_MAX_B	= 837,
    TriCore_MAX_BU	= 838,
    TriCore_MAX_DF_rr	= 839,
    TriCore_MAX_F_rr	= 840,
    TriCore_MAX_H	= 841,
    TriCore_MAX_HU	= 842,
    TriCore_MAX_U_rc	= 843,
    TriCore_MAX_U_rr	= 844,
    TriCore_MAX_rc	= 845,
    TriCore_MAX_rr	= 846,
    TriCore_MFCR_rlc	= 847,
    TriCore_MIN_B	= 848,
    TriCore_MIN_BU	= 849,
    TriCore_MIN_DF_rr	= 850,
    TriCore_MIN_F_rr	= 851,
    TriCore_MIN_H	= 852,
    TriCore_MIN_HU	= 853,
    TriCore_MIN_U_rc	= 854,
    TriCore_MIN_U_rr	= 855,
    TriCore_MIN_rc	= 856,
    TriCore_MIN_rr	= 857,
    TriCore_MOVH_A_rlc	= 858,
    TriCore_MOVH_rlc	= 859,
    TriCore_MOVZ_A_sr	= 860,
    TriCore_MOV_AA_rr	= 861,
    TriCore_MOV_AA_srr_srr	= 862,
    TriCore_MOV_AA_srr_srr_v110	= 863,
    TriCore_MOV_A_rr	= 864,
    TriCore_MOV_A_src	= 865,
    TriCore_MOV_A_srr	= 866,
    TriCore_MOV_A_srr_v110	= 867,
    TriCore_MOV_D_rr	= 868,
    TriCore_MOV_D_srr_srr	= 869,
    TriCore_MOV_D_srr_srr_v110	= 870,
    TriCore_MOV_U_rlc	= 871,
    TriCore_MOV_rlc	= 872,
    TriCore_MOV_rlc_e	= 873,
    TriCore_MOV_rr	= 874,
    TriCore_MOV_rr_e	= 875,
    TriCore_MOV_rr_eab	= 876,
    TriCore_MOV_sc	= 877,
    TriCore_MOV_sc_v110	= 878,
    TriCore_MOV_src	= 879,
    TriCore_MOV_src_e	= 880,
    TriCore_MOV_srr	= 881,
    TriCore_MSUBADMS_H_rrr1_LL	= 882,
    TriCore_MSUBADMS_H_rrr1_LU	= 883,
    TriCore_MSUBADMS_H_rrr1_UL	= 884,
    TriCore_MSUBADMS_H_rrr1_UU	= 885,
    TriCore_MSUBADM_H_rrr1_LL	= 886,
    TriCore_MSUBADM_H_rrr1_LU	= 887,
    TriCore_MSUBADM_H_rrr1_UL	= 888,
    TriCore_MSUBADM_H_rrr1_UU	= 889,
    TriCore_MSUBADRS_H_rrr1_LL	= 890,
    TriCore_MSUBADRS_H_rrr1_LU	= 891,
    TriCore_MSUBADRS_H_rrr1_UL	= 892,
    TriCore_MSUBADRS_H_rrr1_UU	= 893,
    TriCore_MSUBADRS_H_rrr1_v110	= 894,
    TriCore_MSUBADR_H_rrr1_LL	= 895,
    TriCore_MSUBADR_H_rrr1_LU	= 896,
    TriCore_MSUBADR_H_rrr1_UL	= 897,
    TriCore_MSUBADR_H_rrr1_UU	= 898,
    TriCore_MSUBADR_H_rrr1_v110	= 899,
    TriCore_MSUBADS_H_rrr1_LL	= 900,
    TriCore_MSUBADS_H_rrr1_LU	= 901,
    TriCore_MSUBADS_H_rrr1_UL	= 902,
    TriCore_MSUBADS_H_rrr1_UU	= 903,
    TriCore_MSUBAD_H_rrr1_LL	= 904,
    TriCore_MSUBAD_H_rrr1_LU	= 905,
    TriCore_MSUBAD_H_rrr1_UL	= 906,
    TriCore_MSUBAD_H_rrr1_UU	= 907,
    TriCore_MSUBMS_H_rrr1_LL	= 908,
    TriCore_MSUBMS_H_rrr1_LU	= 909,
    TriCore_MSUBMS_H_rrr1_UL	= 910,
    TriCore_MSUBMS_H_rrr1_UU	= 911,
    TriCore_MSUBMS_U_rcrv110	= 912,
    TriCore_MSUBMS_U_rrr2v110	= 913,
    TriCore_MSUBMS_rcrv110	= 914,
    TriCore_MSUBMS_rrr2v110	= 915,
    TriCore_MSUBM_H_rrr1_LL	= 916,
    TriCore_MSUBM_H_rrr1_LU	= 917,
    TriCore_MSUBM_H_rrr1_UL	= 918,
    TriCore_MSUBM_H_rrr1_UU	= 919,
    TriCore_MSUBM_H_rrr1_v110	= 920,
    TriCore_MSUBM_Q_rrr1_v110	= 921,
    TriCore_MSUBM_U_rcrv110	= 922,
    TriCore_MSUBM_U_rrr2v110	= 923,
    TriCore_MSUBM_rcrv110	= 924,
    TriCore_MSUBM_rrr2v110	= 925,
    TriCore_MSUBRS_H_rrr1_LL	= 926,
    TriCore_MSUBRS_H_rrr1_LU	= 927,
    TriCore_MSUBRS_H_rrr1_UL	= 928,
    TriCore_MSUBRS_H_rrr1_UL_2	= 929,
    TriCore_MSUBRS_H_rrr1_UU	= 930,
    TriCore_MSUBRS_H_rrr1_v110	= 931,
    TriCore_MSUBRS_Q_rrr1_L_L	= 932,
    TriCore_MSUBRS_Q_rrr1_U_U	= 933,
    TriCore_MSUBRS_Q_rrr1_v110	= 934,
    TriCore_MSUBR_H_rrr1_LL	= 935,
    TriCore_MSUBR_H_rrr1_LU	= 936,
    TriCore_MSUBR_H_rrr1_UL	= 937,
    TriCore_MSUBR_H_rrr1_UL_2	= 938,
    TriCore_MSUBR_H_rrr1_UU	= 939,
    TriCore_MSUBR_H_rrr1_v110	= 940,
    TriCore_MSUBR_Q_rrr1_L_L	= 941,
    TriCore_MSUBR_Q_rrr1_U_U	= 942,
    TriCore_MSUBR_Q_rrr1_v110	= 943,
    TriCore_MSUBS_H_rrr1_LL	= 944,
    TriCore_MSUBS_H_rrr1_LU	= 945,
    TriCore_MSUBS_H_rrr1_UL	= 946,
    TriCore_MSUBS_H_rrr1_UU	= 947,
    TriCore_MSUBS_H_rrr1_v110	= 948,
    TriCore_MSUBS_Q_rrr1	= 949,
    TriCore_MSUBS_Q_rrr1_L	= 950,
    TriCore_MSUBS_Q_rrr1_L_L	= 951,
    TriCore_MSUBS_Q_rrr1_U	= 952,
    TriCore_MSUBS_Q_rrr1_UU2_v110	= 953,
    TriCore_MSUBS_Q_rrr1_U_U	= 954,
    TriCore_MSUBS_Q_rrr1_e	= 955,
    TriCore_MSUBS_Q_rrr1_e_L	= 956,
    TriCore_MSUBS_Q_rrr1_e_L_L	= 957,
    TriCore_MSUBS_Q_rrr1_e_U	= 958,
    TriCore_MSUBS_Q_rrr1_e_U_U	= 959,
    TriCore_MSUBS_U_rcr	= 960,
    TriCore_MSUBS_U_rcr_e	= 961,
    TriCore_MSUBS_U_rrr2	= 962,
    TriCore_MSUBS_U_rrr2_e	= 963,
    TriCore_MSUBS_rcr	= 964,
    TriCore_MSUBS_rcr_e	= 965,
    TriCore_MSUBS_rrr2	= 966,
    TriCore_MSUBS_rrr2_e	= 967,
    TriCore_MSUB_DF_rrr	= 968,
    TriCore_MSUB_F_rrr	= 969,
    TriCore_MSUB_H_rrr1_LL	= 970,
    TriCore_MSUB_H_rrr1_LU	= 971,
    TriCore_MSUB_H_rrr1_UL	= 972,
    TriCore_MSUB_H_rrr1_UU	= 973,
    TriCore_MSUB_H_rrr1_v110	= 974,
    TriCore_MSUB_Q_rrr1	= 975,
    TriCore_MSUB_Q_rrr1_L	= 976,
    TriCore_MSUB_Q_rrr1_L_L	= 977,
    TriCore_MSUB_Q_rrr1_U	= 978,
    TriCore_MSUB_Q_rrr1_UU2_v110	= 979,
    TriCore_MSUB_Q_rrr1_U_U	= 980,
    TriCore_MSUB_Q_rrr1_e	= 981,
    TriCore_MSUB_Q_rrr1_e_L	= 982,
    TriCore_MSUB_Q_rrr1_e_L_L	= 983,
    TriCore_MSUB_Q_rrr1_e_U	= 984,
    TriCore_MSUB_Q_rrr1_e_U_U	= 985,
    TriCore_MSUB_U_rcr	= 986,
    TriCore_MSUB_U_rrr2	= 987,
    TriCore_MSUB_rcr	= 988,
    TriCore_MSUB_rcr_e	= 989,
    TriCore_MSUB_rrr2	= 990,
    TriCore_MSUB_rrr2_e	= 991,
    TriCore_MTCR_rlc	= 992,
    TriCore_MULMS_H_rr1_LL2e	= 993,
    TriCore_MULMS_H_rr1_LU2e	= 994,
    TriCore_MULMS_H_rr1_UL2e	= 995,
    TriCore_MULMS_H_rr1_UU2e	= 996,
    TriCore_MULM_H_rr1_LL2e	= 997,
    TriCore_MULM_H_rr1_LU2e	= 998,
    TriCore_MULM_H_rr1_UL2e	= 999,
    TriCore_MULM_H_rr1_UU2e	= 1000,
    TriCore_MULM_U_rc	= 1001,
    TriCore_MULM_U_rr	= 1002,
    TriCore_MULM_rc	= 1003,
    TriCore_MULM_rr	= 1004,
    TriCore_MULR_H_rr1_LL2e	= 1005,
    TriCore_MULR_H_rr1_LU2e	= 1006,
    TriCore_MULR_H_rr1_UL2e	= 1007,
    TriCore_MULR_H_rr1_UU2e	= 1008,
    TriCore_MULR_H_rr_v110	= 1009,
    TriCore_MULR_Q_rr1_2LL	= 1010,
    TriCore_MULR_Q_rr1_2UU	= 1011,
    TriCore_MULR_Q_rr_v110	= 1012,
    TriCore_MULS_U_rc	= 1013,
    TriCore_MULS_U_rr2	= 1014,
    TriCore_MULS_U_rr_v110	= 1015,
    TriCore_MULS_rc	= 1016,
    TriCore_MULS_rr2	= 1017,
    TriCore_MULS_rr_v110	= 1018,
    TriCore_MUL_DF_rrr	= 1019,
    TriCore_MUL_F_rrr	= 1020,
    TriCore_MUL_H_rr1_LL2e	= 1021,
    TriCore_MUL_H_rr1_LU2e	= 1022,
    TriCore_MUL_H_rr1_UL2e	= 1023,
    TriCore_MUL_H_rr1_UU2e	= 1024,
    TriCore_MUL_H_rr_v110	= 1025,
    TriCore_MUL_Q_rr1_2	= 1026,
    TriCore_MUL_Q_rr1_2LL	= 1027,
    TriCore_MUL_Q_rr1_2UU	= 1028,
    TriCore_MUL_Q_rr1_2_L	= 1029,
    TriCore_MUL_Q_rr1_2_Le	= 1030,
    TriCore_MUL_Q_rr1_2_U	= 1031,
    TriCore_MUL_Q_rr1_2_Ue	= 1032,
    TriCore_MUL_Q_rr1_2__e	= 1033,
    TriCore_MUL_Q_rr_v110	= 1034,
    TriCore_MUL_U_rc	= 1035,
    TriCore_MUL_U_rr2	= 1036,
    TriCore_MUL_rc	= 1037,
    TriCore_MUL_rc_e	= 1038,
    TriCore_MUL_rr2	= 1039,
    TriCore_MUL_rr2_e	= 1040,
    TriCore_MUL_rr_v110	= 1041,
    TriCore_MUL_srr	= 1042,
    TriCore_NAND_T	= 1043,
    TriCore_NAND_rc	= 1044,
    TriCore_NAND_rr	= 1045,
    TriCore_NEG_DF_rr	= 1046,
    TriCore_NEG_F_rr	= 1047,
    TriCore_NEZ_A	= 1048,
    TriCore_NE_A	= 1049,
    TriCore_NE_rc	= 1050,
    TriCore_NE_rr	= 1051,
    TriCore_NOP_sr	= 1052,
    TriCore_NOP_sys	= 1053,
    TriCore_NOR_T	= 1054,
    TriCore_NOR_rc	= 1055,
    TriCore_NOR_rr	= 1056,
    TriCore_NOT_sr	= 1057,
    TriCore_ORN_T	= 1058,
    TriCore_ORN_rc	= 1059,
    TriCore_ORN_rr	= 1060,
    TriCore_OR_ANDN_T	= 1061,
    TriCore_OR_AND_T	= 1062,
    TriCore_OR_EQ_rc	= 1063,
    TriCore_OR_EQ_rr	= 1064,
    TriCore_OR_GE_U_rc	= 1065,
    TriCore_OR_GE_U_rr	= 1066,
    TriCore_OR_GE_rc	= 1067,
    TriCore_OR_GE_rr	= 1068,
    TriCore_OR_LT_U_rc	= 1069,
    TriCore_OR_LT_U_rr	= 1070,
    TriCore_OR_LT_rc	= 1071,
    TriCore_OR_LT_rr	= 1072,
    TriCore_OR_NE_rc	= 1073,
    TriCore_OR_NE_rr	= 1074,
    TriCore_OR_NOR_T	= 1075,
    TriCore_OR_OR_T	= 1076,
    TriCore_OR_T	= 1077,
    TriCore_OR_rc	= 1078,
    TriCore_OR_rr	= 1079,
    TriCore_OR_sc	= 1080,
    TriCore_OR_sc_v110	= 1081,
    TriCore_OR_srr	= 1082,
    TriCore_OR_srr_v110	= 1083,
    TriCore_PACK_rrr	= 1084,
    TriCore_PARITY_rr	= 1085,
    TriCore_PARITY_rr_v110	= 1086,
    TriCore_POPCNT_W_rr	= 1087,
    TriCore_Q31TOF_rr	= 1088,
    TriCore_QSEED_DF_rr	= 1089,
    TriCore_QSEED_F_rr	= 1090,
    TriCore_REM64_U_rr	= 1091,
    TriCore_REM64_rr	= 1092,
    TriCore_RESTORE_sys	= 1093,
    TriCore_RET_sr	= 1094,
    TriCore_RET_sys	= 1095,
    TriCore_RET_sys_v110	= 1096,
    TriCore_RFE_sr	= 1097,
    TriCore_RFE_sys_sys	= 1098,
    TriCore_RFE_sys_sys_v110	= 1099,
    TriCore_RFM_sys	= 1100,
    TriCore_RSLCX_sys	= 1101,
    TriCore_RSTV_sys	= 1102,
    TriCore_RSUBS_U_rc	= 1103,
    TriCore_RSUBS_rc	= 1104,
    TriCore_RSUB_rc	= 1105,
    TriCore_RSUB_sr_sr	= 1106,
    TriCore_RSUB_sr_sr_v110	= 1107,
    TriCore_SAT_BU_rr	= 1108,
    TriCore_SAT_BU_sr	= 1109,
    TriCore_SAT_BU_sr_v110	= 1110,
    TriCore_SAT_B_rr	= 1111,
    TriCore_SAT_B_sr	= 1112,
    TriCore_SAT_B_sr_v110	= 1113,
    TriCore_SAT_HU_rr	= 1114,
    TriCore_SAT_HU_sr	= 1115,
    TriCore_SAT_HU_sr_v110	= 1116,
    TriCore_SAT_H_rr	= 1117,
    TriCore_SAT_H_sr	= 1118,
    TriCore_SAT_H_sr_v110	= 1119,
    TriCore_SELN_A_rcr_v110	= 1120,
    TriCore_SELN_A_rrr_v110	= 1121,
    TriCore_SELN_rcr	= 1122,
    TriCore_SELN_rrr	= 1123,
    TriCore_SEL_A_rcr_v110	= 1124,
    TriCore_SEL_A_rrr_v110	= 1125,
    TriCore_SEL_rcr	= 1126,
    TriCore_SEL_rrr	= 1127,
    TriCore_SHAS_rc	= 1128,
    TriCore_SHAS_rr	= 1129,
    TriCore_SHA_B_rc	= 1130,
    TriCore_SHA_B_rr	= 1131,
    TriCore_SHA_H_rc	= 1132,
    TriCore_SHA_H_rr	= 1133,
    TriCore_SHA_rc	= 1134,
    TriCore_SHA_rr	= 1135,
    TriCore_SHA_src	= 1136,
    TriCore_SHA_src_v110	= 1137,
    TriCore_SHUFFLE_rc	= 1138,
    TriCore_SH_ANDN_T	= 1139,
    TriCore_SH_AND_T	= 1140,
    TriCore_SH_B_rc	= 1141,
    TriCore_SH_B_rr	= 1142,
    TriCore_SH_EQ_rc	= 1143,
    TriCore_SH_EQ_rr	= 1144,
    TriCore_SH_GE_U_rc	= 1145,
    TriCore_SH_GE_U_rr	= 1146,
    TriCore_SH_GE_rc	= 1147,
    TriCore_SH_GE_rr	= 1148,
    TriCore_SH_H_rc	= 1149,
    TriCore_SH_H_rr	= 1150,
    TriCore_SH_LT_U_rc	= 1151,
    TriCore_SH_LT_U_rr	= 1152,
    TriCore_SH_LT_rc	= 1153,
    TriCore_SH_LT_rr	= 1154,
    TriCore_SH_NAND_T	= 1155,
    TriCore_SH_NE_rc	= 1156,
    TriCore_SH_NE_rr	= 1157,
    TriCore_SH_NOR_T	= 1158,
    TriCore_SH_ORN_T	= 1159,
    TriCore_SH_OR_T	= 1160,
    TriCore_SH_XNOR_T	= 1161,
    TriCore_SH_XOR_T	= 1162,
    TriCore_SH_rc	= 1163,
    TriCore_SH_rr	= 1164,
    TriCore_SH_src	= 1165,
    TriCore_SH_src_v110	= 1166,
    TriCore_STLCX_abs	= 1167,
    TriCore_STLCX_bo_bso	= 1168,
    TriCore_STUCX_abs	= 1169,
    TriCore_STUCX_bo_bso	= 1170,
    TriCore_ST_A_abs	= 1171,
    TriCore_ST_A_bo_bso	= 1172,
    TriCore_ST_A_bo_c	= 1173,
    TriCore_ST_A_bo_pos	= 1174,
    TriCore_ST_A_bo_pre	= 1175,
    TriCore_ST_A_bo_r	= 1176,
    TriCore_ST_A_bol	= 1177,
    TriCore_ST_A_sc	= 1178,
    TriCore_ST_A_sro	= 1179,
    TriCore_ST_A_sro_v110	= 1180,
    TriCore_ST_A_ssr	= 1181,
    TriCore_ST_A_ssr_pos	= 1182,
    TriCore_ST_A_ssr_pos_v110	= 1183,
    TriCore_ST_A_ssr_v110	= 1184,
    TriCore_ST_A_ssro	= 1185,
    TriCore_ST_A_ssro_v110	= 1186,
    TriCore_ST_B_abs	= 1187,
    TriCore_ST_B_bo_bso	= 1188,
    TriCore_ST_B_bo_c	= 1189,
    TriCore_ST_B_bo_pos	= 1190,
    TriCore_ST_B_bo_pre	= 1191,
    TriCore_ST_B_bo_r	= 1192,
    TriCore_ST_B_bol	= 1193,
    TriCore_ST_B_sro	= 1194,
    TriCore_ST_B_sro_v110	= 1195,
    TriCore_ST_B_ssr	= 1196,
    TriCore_ST_B_ssr_pos	= 1197,
    TriCore_ST_B_ssr_pos_v110	= 1198,
    TriCore_ST_B_ssr_v110	= 1199,
    TriCore_ST_B_ssro	= 1200,
    TriCore_ST_B_ssro_v110	= 1201,
    TriCore_ST_DA_abs	= 1202,
    TriCore_ST_DA_bo_bso	= 1203,
    TriCore_ST_DA_bo_c	= 1204,
    TriCore_ST_DA_bo_pos	= 1205,
    TriCore_ST_DA_bo_pre	= 1206,
    TriCore_ST_DA_bo_r	= 1207,
    TriCore_ST_D_abs	= 1208,
    TriCore_ST_D_bo_bso	= 1209,
    TriCore_ST_D_bo_c	= 1210,
    TriCore_ST_D_bo_pos	= 1211,
    TriCore_ST_D_bo_pre	= 1212,
    TriCore_ST_D_bo_r	= 1213,
    TriCore_ST_H_abs	= 1214,
    TriCore_ST_H_bo_bso	= 1215,
    TriCore_ST_H_bo_c	= 1216,
    TriCore_ST_H_bo_pos	= 1217,
    TriCore_ST_H_bo_pre	= 1218,
    TriCore_ST_H_bo_r	= 1219,
    TriCore_ST_H_bol	= 1220,
    TriCore_ST_H_sro	= 1221,
    TriCore_ST_H_sro_v110	= 1222,
    TriCore_ST_H_ssr	= 1223,
    TriCore_ST_H_ssr_pos	= 1224,
    TriCore_ST_H_ssr_pos_v110	= 1225,
    TriCore_ST_H_ssr_v110	= 1226,
    TriCore_ST_H_ssro	= 1227,
    TriCore_ST_H_ssro_v110	= 1228,
    TriCore_ST_Q_abs	= 1229,
    TriCore_ST_Q_bo_bso	= 1230,
    TriCore_ST_Q_bo_c	= 1231,
    TriCore_ST_Q_bo_pos	= 1232,
    TriCore_ST_Q_bo_pre	= 1233,
    TriCore_ST_Q_bo_r	= 1234,
    TriCore_ST_T	= 1235,
    TriCore_ST_W_abs	= 1236,
    TriCore_ST_W_bo_bso	= 1237,
    TriCore_ST_W_bo_c	= 1238,
    TriCore_ST_W_bo_pos	= 1239,
    TriCore_ST_W_bo_pre	= 1240,
    TriCore_ST_W_bo_r	= 1241,
    TriCore_ST_W_bol	= 1242,
    TriCore_ST_W_sc	= 1243,
    TriCore_ST_W_sro	= 1244,
    TriCore_ST_W_sro_v110	= 1245,
    TriCore_ST_W_ssr	= 1246,
    TriCore_ST_W_ssr_pos	= 1247,
    TriCore_ST_W_ssr_pos_v110	= 1248,
    TriCore_ST_W_ssr_v110	= 1249,
    TriCore_ST_W_ssro	= 1250,
    TriCore_ST_W_ssro_v110	= 1251,
    TriCore_SUBC_rr	= 1252,
    TriCore_SUBSC_A_rr	= 1253,
    TriCore_SUBS_BU_rr	= 1254,
    TriCore_SUBS_B_rr	= 1255,
    TriCore_SUBS_HU_rr	= 1256,
    TriCore_SUBS_H_rr	= 1257,
    TriCore_SUBS_U_rr	= 1258,
    TriCore_SUBS_rr	= 1259,
    TriCore_SUBS_srr	= 1260,
    TriCore_SUBX_rr	= 1261,
    TriCore_SUB_A_rr	= 1262,
    TriCore_SUB_A_sc	= 1263,
    TriCore_SUB_A_sc_v110	= 1264,
    TriCore_SUB_B_rr	= 1265,
    TriCore_SUB_DF_rrr	= 1266,
    TriCore_SUB_F_rrr	= 1267,
    TriCore_SUB_H_rr	= 1268,
    TriCore_SUB_rr	= 1269,
    TriCore_SUB_srr	= 1270,
    TriCore_SUB_srr_15a	= 1271,
    TriCore_SUB_srr_a15	= 1272,
    TriCore_SVLCX_sys	= 1273,
    TriCore_SWAPMSK_W_bo_bso	= 1274,
    TriCore_SWAPMSK_W_bo_c	= 1275,
    TriCore_SWAPMSK_W_bo_i	= 1276,
    TriCore_SWAPMSK_W_bo_pos	= 1277,
    TriCore_SWAPMSK_W_bo_pre	= 1278,
    TriCore_SWAPMSK_W_bo_r	= 1279,
    TriCore_SWAP_A_abs	= 1280,
    TriCore_SWAP_A_bo_bso	= 1281,
    TriCore_SWAP_A_bo_c	= 1282,
    TriCore_SWAP_A_bo_pos	= 1283,
    TriCore_SWAP_A_bo_pre	= 1284,
    TriCore_SWAP_A_bo_r	= 1285,
    TriCore_SWAP_W_abs	= 1286,
    TriCore_SWAP_W_bo_bso	= 1287,
    TriCore_SWAP_W_bo_c	= 1288,
    TriCore_SWAP_W_bo_i	= 1289,
    TriCore_SWAP_W_bo_pos	= 1290,
    TriCore_SWAP_W_bo_pre	= 1291,
    TriCore_SWAP_W_bo_r	= 1292,
    TriCore_SYSCALL_rc	= 1293,
    TriCore_TLBDEMAP_rr	= 1294,
    TriCore_TLBFLUSH_A_rr	= 1295,
    TriCore_TLBFLUSH_B_rr	= 1296,
    TriCore_TLBMAP_rr	= 1297,
    TriCore_TLBPROBE_A_rr	= 1298,
    TriCore_TLBPROBE_I_rr	= 1299,
    TriCore_TRAPSV_sys	= 1300,
    TriCore_TRAPV_sys	= 1301,
    TriCore_ULTODF_rr	= 1302,
    TriCore_UNPACK_rr_rr	= 1303,
    TriCore_UNPACK_rr_rr_v110	= 1304,
    TriCore_UPDFL_rr	= 1305,
    TriCore_UTODF_rr	= 1306,
    TriCore_UTOF_rr	= 1307,
    TriCore_WAIT_sys	= 1308,
    TriCore_XNOR_T	= 1309,
    TriCore_XNOR_rc	= 1310,
    TriCore_XNOR_rr	= 1311,
    TriCore_XOR_EQ_rc	= 1312,
    TriCore_XOR_EQ_rr	= 1313,
    TriCore_XOR_GE_U_rc	= 1314,
    TriCore_XOR_GE_U_rr	= 1315,
    TriCore_XOR_GE_rc	= 1316,
    TriCore_XOR_GE_rr	= 1317,
    TriCore_XOR_LT_U_rc	= 1318,
    TriCore_XOR_LT_U_rr	= 1319,
    TriCore_XOR_LT_rc	= 1320,
    TriCore_XOR_LT_rr	= 1321,
    TriCore_XOR_NE_rc	= 1322,
    TriCore_XOR_NE_rr	= 1323,
    TriCore_XOR_T	= 1324,
    TriCore_XOR_rc	= 1325,
    TriCore_XOR_rr	= 1326,
    TriCore_XOR_srr	= 1327,
    INSTRUCTION_LIST_END = 1328
  };

#endif // GET_INSTRINFO_ENUM

#if defined(GET_INSTRINFO_MC_DESC) || defined(GET_INSTRINFO_CTOR_DTOR)
typedef struct TriCoreInstrTable {
  MCInstrDesc Insts[1328];
  MCOperandInfo OperandInfo[364];
  MCPhysReg ImplicitOps[3];
} TriCoreInstrTable;

#endif // defined(GET_INSTRINFO_MC_DESC) || defined(GET_INSTRINFO_CTOR_DTOR)

#ifdef GET_INSTRINFO_MC_DESC
#undef GET_INSTRINFO_MC_DESC

static const unsigned TriCoreImpOpBase = sizeof(MCOperandInfo) / (sizeof(MCPhysReg));

static const TriCoreInstrTable TriCoreDescs = {
  {
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #1327 = XOR_srr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1326 = XOR_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1325 = XOR_rc
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #1324 = XOR_T
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1323 = XOR_NE_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1322 = XOR_NE_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1321 = XOR_LT_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1320 = XOR_LT_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1319 = XOR_LT_U_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1318 = XOR_LT_U_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1317 = XOR_GE_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1316 = XOR_GE_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1315 = XOR_GE_U_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1314 = XOR_GE_U_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1313 = XOR_EQ_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1312 = XOR_EQ_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1311 = XNOR_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1310 = XNOR_rc
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #1309 = XNOR_T
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #1308 = WAIT_sys
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #1307 = UTOF_rr
  { 2, &TriCoreDescs.OperandInfo[192] },  // Inst #1306 = UTODF_rr
  { 1, &TriCoreDescs.OperandInfo[228] },  // Inst #1305 = UPDFL_rr
  { 2, &TriCoreDescs.OperandInfo[192] },  // Inst #1304 = UNPACK_rr_rr_v110
  { 2, &TriCoreDescs.OperandInfo[192] },  // Inst #1303 = UNPACK_rr_rr
  { 2, &TriCoreDescs.OperandInfo[148] },  // Inst #1302 = ULTODF_rr
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #1301 = TRAPV_sys
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #1300 = TRAPSV_sys
  { 1, &TriCoreDescs.OperandInfo[228] },  // Inst #1299 = TLBPROBE_I_rr
  { 1, &TriCoreDescs.OperandInfo[228] },  // Inst #1298 = TLBPROBE_A_rr
  { 1, &TriCoreDescs.OperandInfo[363] },  // Inst #1297 = TLBMAP_rr
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #1296 = TLBFLUSH_B_rr
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #1295 = TLBFLUSH_A_rr
  { 1, &TriCoreDescs.OperandInfo[228] },  // Inst #1294 = TLBDEMAP_rr
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #1293 = SYSCALL_rc
  { 2, &TriCoreDescs.OperandInfo[350] },  // Inst #1292 = SWAP_W_bo_r
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #1291 = SWAP_W_bo_pre
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #1290 = SWAP_W_bo_pos
  { 3, &TriCoreDescs.OperandInfo[296] },  // Inst #1289 = SWAP_W_bo_i
  { 3, &TriCoreDescs.OperandInfo[347] },  // Inst #1288 = SWAP_W_bo_c
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #1287 = SWAP_W_bo_bso
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #1286 = SWAP_W_abs
  { 2, &TriCoreDescs.OperandInfo[342] },  // Inst #1285 = SWAP_A_bo_r
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #1284 = SWAP_A_bo_pre
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #1283 = SWAP_A_bo_pos
  { 3, &TriCoreDescs.OperandInfo[301] },  // Inst #1282 = SWAP_A_bo_c
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #1281 = SWAP_A_bo_bso
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #1280 = SWAP_A_abs
  { 2, &TriCoreDescs.OperandInfo[358] },  // Inst #1279 = SWAPMSK_W_bo_r
  { 3, &TriCoreDescs.OperandInfo[206] },  // Inst #1278 = SWAPMSK_W_bo_pre
  { 3, &TriCoreDescs.OperandInfo[206] },  // Inst #1277 = SWAPMSK_W_bo_pos
  { 3, &TriCoreDescs.OperandInfo[209] },  // Inst #1276 = SWAPMSK_W_bo_i
  { 3, &TriCoreDescs.OperandInfo[355] },  // Inst #1275 = SWAPMSK_W_bo_c
  { 3, &TriCoreDescs.OperandInfo[206] },  // Inst #1274 = SWAPMSK_W_bo_bso
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #1273 = SVLCX_sys
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1272 = SUB_srr_a15
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1271 = SUB_srr_15a
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #1270 = SUB_srr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1269 = SUB_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1268 = SUB_H_rr
  { 4, &TriCoreDescs.OperandInfo[181] },  // Inst #1267 = SUB_F_rrr
  { 4, &TriCoreDescs.OperandInfo[177] },  // Inst #1266 = SUB_DF_rrr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1265 = SUB_B_rr
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #1264 = SUB_A_sc_v110
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #1263 = SUB_A_sc
  { 3, &TriCoreDescs.OperandInfo[170] },  // Inst #1262 = SUB_A_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1261 = SUBX_rr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #1260 = SUBS_srr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1259 = SUBS_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1258 = SUBS_U_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1257 = SUBS_H_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1256 = SUBS_HU_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1255 = SUBS_B_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1254 = SUBS_BU_rr
  { 4, &TriCoreDescs.OperandInfo[163] },  // Inst #1253 = SUBSC_A_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1252 = SUBC_rr
  { 3, &TriCoreDescs.OperandInfo[167] },  // Inst #1251 = ST_W_ssro_v110
  { 3, &TriCoreDescs.OperandInfo[167] },  // Inst #1250 = ST_W_ssro
  { 2, &TriCoreDescs.OperandInfo[331] },  // Inst #1249 = ST_W_ssr_v110
  { 2, &TriCoreDescs.OperandInfo[331] },  // Inst #1248 = ST_W_ssr_pos_v110
  { 2, &TriCoreDescs.OperandInfo[331] },  // Inst #1247 = ST_W_ssr_pos
  { 2, &TriCoreDescs.OperandInfo[331] },  // Inst #1246 = ST_W_ssr
  { 3, &TriCoreDescs.OperandInfo[352] },  // Inst #1245 = ST_W_sro_v110
  { 3, &TriCoreDescs.OperandInfo[352] },  // Inst #1244 = ST_W_sro
  { 3, &TriCoreDescs.OperandInfo[352] },  // Inst #1243 = ST_W_sc
  { 3, &TriCoreDescs.OperandInfo[167] },  // Inst #1242 = ST_W_bol
  { 2, &TriCoreDescs.OperandInfo[350] },  // Inst #1241 = ST_W_bo_r
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #1240 = ST_W_bo_pre
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #1239 = ST_W_bo_pos
  { 3, &TriCoreDescs.OperandInfo[347] },  // Inst #1238 = ST_W_bo_c
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #1237 = ST_W_bo_bso
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #1236 = ST_W_abs
  { 3, &TriCoreDescs.OperandInfo[360] },  // Inst #1235 = ST_T
  { 2, &TriCoreDescs.OperandInfo[350] },  // Inst #1234 = ST_Q_bo_r
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #1233 = ST_Q_bo_pre
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #1232 = ST_Q_bo_pos
  { 3, &TriCoreDescs.OperandInfo[347] },  // Inst #1231 = ST_Q_bo_c
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #1230 = ST_Q_bo_bso
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #1229 = ST_Q_abs
  { 3, &TriCoreDescs.OperandInfo[167] },  // Inst #1228 = ST_H_ssro_v110
  { 3, &TriCoreDescs.OperandInfo[167] },  // Inst #1227 = ST_H_ssro
  { 2, &TriCoreDescs.OperandInfo[331] },  // Inst #1226 = ST_H_ssr_v110
  { 2, &TriCoreDescs.OperandInfo[331] },  // Inst #1225 = ST_H_ssr_pos_v110
  { 2, &TriCoreDescs.OperandInfo[331] },  // Inst #1224 = ST_H_ssr_pos
  { 2, &TriCoreDescs.OperandInfo[331] },  // Inst #1223 = ST_H_ssr
  { 3, &TriCoreDescs.OperandInfo[352] },  // Inst #1222 = ST_H_sro_v110
  { 3, &TriCoreDescs.OperandInfo[352] },  // Inst #1221 = ST_H_sro
  { 3, &TriCoreDescs.OperandInfo[167] },  // Inst #1220 = ST_H_bol
  { 2, &TriCoreDescs.OperandInfo[350] },  // Inst #1219 = ST_H_bo_r
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #1218 = ST_H_bo_pre
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #1217 = ST_H_bo_pos
  { 3, &TriCoreDescs.OperandInfo[347] },  // Inst #1216 = ST_H_bo_c
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #1215 = ST_H_bo_bso
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #1214 = ST_H_abs
  { 2, &TriCoreDescs.OperandInfo[358] },  // Inst #1213 = ST_D_bo_r
  { 3, &TriCoreDescs.OperandInfo[206] },  // Inst #1212 = ST_D_bo_pre
  { 3, &TriCoreDescs.OperandInfo[206] },  // Inst #1211 = ST_D_bo_pos
  { 3, &TriCoreDescs.OperandInfo[355] },  // Inst #1210 = ST_D_bo_c
  { 3, &TriCoreDescs.OperandInfo[206] },  // Inst #1209 = ST_D_bo_bso
  { 2, &TriCoreDescs.OperandInfo[286] },  // Inst #1208 = ST_D_abs
  { 2, &TriCoreDescs.OperandInfo[307] },  // Inst #1207 = ST_DA_bo_r
  { 3, &TriCoreDescs.OperandInfo[301] },  // Inst #1206 = ST_DA_bo_pre
  { 3, &TriCoreDescs.OperandInfo[301] },  // Inst #1205 = ST_DA_bo_pos
  { 3, &TriCoreDescs.OperandInfo[304] },  // Inst #1204 = ST_DA_bo_c
  { 3, &TriCoreDescs.OperandInfo[301] },  // Inst #1203 = ST_DA_bo_bso
  { 2, &TriCoreDescs.OperandInfo[194] },  // Inst #1202 = ST_DA_abs
  { 3, &TriCoreDescs.OperandInfo[167] },  // Inst #1201 = ST_B_ssro_v110
  { 3, &TriCoreDescs.OperandInfo[167] },  // Inst #1200 = ST_B_ssro
  { 2, &TriCoreDescs.OperandInfo[331] },  // Inst #1199 = ST_B_ssr_v110
  { 2, &TriCoreDescs.OperandInfo[331] },  // Inst #1198 = ST_B_ssr_pos_v110
  { 2, &TriCoreDescs.OperandInfo[331] },  // Inst #1197 = ST_B_ssr_pos
  { 2, &TriCoreDescs.OperandInfo[331] },  // Inst #1196 = ST_B_ssr
  { 3, &TriCoreDescs.OperandInfo[352] },  // Inst #1195 = ST_B_sro_v110
  { 3, &TriCoreDescs.OperandInfo[352] },  // Inst #1194 = ST_B_sro
  { 3, &TriCoreDescs.OperandInfo[167] },  // Inst #1193 = ST_B_bol
  { 2, &TriCoreDescs.OperandInfo[350] },  // Inst #1192 = ST_B_bo_r
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #1191 = ST_B_bo_pre
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #1190 = ST_B_bo_pos
  { 3, &TriCoreDescs.OperandInfo[347] },  // Inst #1189 = ST_B_bo_c
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #1188 = ST_B_bo_bso
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #1187 = ST_B_abs
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #1186 = ST_A_ssro_v110
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #1185 = ST_A_ssro
  { 2, &TriCoreDescs.OperandInfo[175] },  // Inst #1184 = ST_A_ssr_v110
  { 2, &TriCoreDescs.OperandInfo[175] },  // Inst #1183 = ST_A_ssr_pos_v110
  { 2, &TriCoreDescs.OperandInfo[175] },  // Inst #1182 = ST_A_ssr_pos
  { 2, &TriCoreDescs.OperandInfo[175] },  // Inst #1181 = ST_A_ssr
  { 3, &TriCoreDescs.OperandInfo[344] },  // Inst #1180 = ST_A_sro_v110
  { 3, &TriCoreDescs.OperandInfo[344] },  // Inst #1179 = ST_A_sro
  { 3, &TriCoreDescs.OperandInfo[344] },  // Inst #1178 = ST_A_sc
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #1177 = ST_A_bol
  { 2, &TriCoreDescs.OperandInfo[342] },  // Inst #1176 = ST_A_bo_r
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #1175 = ST_A_bo_pre
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #1174 = ST_A_bo_pos
  { 3, &TriCoreDescs.OperandInfo[301] },  // Inst #1173 = ST_A_bo_c
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #1172 = ST_A_bo_bso
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #1171 = ST_A_abs
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #1170 = STUCX_bo_bso
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #1169 = STUCX_abs
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #1168 = STLCX_bo_bso
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #1167 = STLCX_abs
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #1166 = SH_src_v110
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #1165 = SH_src
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1164 = SH_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1163 = SH_rc
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #1162 = SH_XOR_T
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #1161 = SH_XNOR_T
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #1160 = SH_OR_T
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #1159 = SH_ORN_T
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #1158 = SH_NOR_T
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1157 = SH_NE_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1156 = SH_NE_rc
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #1155 = SH_NAND_T
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1154 = SH_LT_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1153 = SH_LT_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1152 = SH_LT_U_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1151 = SH_LT_U_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1150 = SH_H_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1149 = SH_H_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1148 = SH_GE_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1147 = SH_GE_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1146 = SH_GE_U_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1145 = SH_GE_U_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1144 = SH_EQ_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1143 = SH_EQ_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1142 = SH_B_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1141 = SH_B_rc
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #1140 = SH_AND_T
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #1139 = SH_ANDN_T
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1138 = SHUFFLE_rc
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #1137 = SHA_src_v110
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #1136 = SHA_src
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1135 = SHA_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1134 = SHA_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1133 = SHA_H_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1132 = SHA_H_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1131 = SHA_B_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1130 = SHA_B_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1129 = SHAS_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1128 = SHAS_rc
  { 4, &TriCoreDescs.OperandInfo[181] },  // Inst #1127 = SEL_rrr
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #1126 = SEL_rcr
  { 4, &TriCoreDescs.OperandInfo[197] },  // Inst #1125 = SEL_A_rrr_v110
  { 4, &TriCoreDescs.OperandInfo[163] },  // Inst #1124 = SEL_A_rcr_v110
  { 4, &TriCoreDescs.OperandInfo[181] },  // Inst #1123 = SELN_rrr
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #1122 = SELN_rcr
  { 4, &TriCoreDescs.OperandInfo[197] },  // Inst #1121 = SELN_A_rrr_v110
  { 4, &TriCoreDescs.OperandInfo[163] },  // Inst #1120 = SELN_A_rcr_v110
  { 1, &TriCoreDescs.OperandInfo[228] },  // Inst #1119 = SAT_H_sr_v110
  { 1, &TriCoreDescs.OperandInfo[228] },  // Inst #1118 = SAT_H_sr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #1117 = SAT_H_rr
  { 1, &TriCoreDescs.OperandInfo[228] },  // Inst #1116 = SAT_HU_sr_v110
  { 1, &TriCoreDescs.OperandInfo[228] },  // Inst #1115 = SAT_HU_sr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #1114 = SAT_HU_rr
  { 1, &TriCoreDescs.OperandInfo[228] },  // Inst #1113 = SAT_B_sr_v110
  { 1, &TriCoreDescs.OperandInfo[228] },  // Inst #1112 = SAT_B_sr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #1111 = SAT_B_rr
  { 1, &TriCoreDescs.OperandInfo[228] },  // Inst #1110 = SAT_BU_sr_v110
  { 1, &TriCoreDescs.OperandInfo[228] },  // Inst #1109 = SAT_BU_sr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #1108 = SAT_BU_rr
  { 1, &TriCoreDescs.OperandInfo[228] },  // Inst #1107 = RSUB_sr_sr_v110
  { 1, &TriCoreDescs.OperandInfo[228] },  // Inst #1106 = RSUB_sr_sr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1105 = RSUB_rc
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1104 = RSUBS_rc
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1103 = RSUBS_U_rc
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #1102 = RSTV_sys
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #1101 = RSLCX_sys
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #1100 = RFM_sys
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #1099 = RFE_sys_sys_v110
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #1098 = RFE_sys_sys
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #1097 = RFE_sr
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #1096 = RET_sys_v110
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #1095 = RET_sys
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #1094 = RET_sr
  { 1, &TriCoreDescs.OperandInfo[228] },  // Inst #1093 = RESTORE_sys
  { 3, &TriCoreDescs.OperandInfo[229] },  // Inst #1092 = REM64_rr
  { 3, &TriCoreDescs.OperandInfo[229] },  // Inst #1091 = REM64_U_rr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #1090 = QSEED_F_rr
  { 2, &TriCoreDescs.OperandInfo[148] },  // Inst #1089 = QSEED_DF_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1088 = Q31TOF_rr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #1087 = POPCNT_W_rr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #1086 = PARITY_rr_v110
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #1085 = PARITY_rr
  { 4, &TriCoreDescs.OperandInfo[276] },  // Inst #1084 = PACK_rrr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #1083 = OR_srr_v110
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #1082 = OR_srr
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #1081 = OR_sc_v110
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #1080 = OR_sc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1079 = OR_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1078 = OR_rc
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #1077 = OR_T
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #1076 = OR_OR_T
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #1075 = OR_NOR_T
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1074 = OR_NE_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1073 = OR_NE_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1072 = OR_LT_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1071 = OR_LT_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1070 = OR_LT_U_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1069 = OR_LT_U_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1068 = OR_GE_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1067 = OR_GE_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1066 = OR_GE_U_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1065 = OR_GE_U_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1064 = OR_EQ_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1063 = OR_EQ_rc
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #1062 = OR_AND_T
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #1061 = OR_ANDN_T
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1060 = ORN_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1059 = ORN_rc
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #1058 = ORN_T
  { 1, &TriCoreDescs.OperandInfo[228] },  // Inst #1057 = NOT_sr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1056 = NOR_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1055 = NOR_rc
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #1054 = NOR_T
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #1053 = NOP_sys
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #1052 = NOP_sr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1051 = NE_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1050 = NE_rc
  { 3, &TriCoreDescs.OperandInfo[241] },  // Inst #1049 = NE_A
  { 2, &TriCoreDescs.OperandInfo[239] },  // Inst #1048 = NEZ_A
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #1047 = NEG_F_rr
  { 2, &TriCoreDescs.OperandInfo[148] },  // Inst #1046 = NEG_DF_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1045 = NAND_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1044 = NAND_rc
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #1043 = NAND_T
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #1042 = MUL_srr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1041 = MUL_rr_v110
  { 3, &TriCoreDescs.OperandInfo[232] },  // Inst #1040 = MUL_rr2_e
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1039 = MUL_rr2
  { 3, &TriCoreDescs.OperandInfo[339] },  // Inst #1038 = MUL_rc_e
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1037 = MUL_rc
  { 3, &TriCoreDescs.OperandInfo[232] },  // Inst #1036 = MUL_U_rr2
  { 3, &TriCoreDescs.OperandInfo[339] },  // Inst #1035 = MUL_U_rc
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #1034 = MUL_Q_rr_v110
  { 4, &TriCoreDescs.OperandInfo[335] },  // Inst #1033 = MUL_Q_rr1_2__e
  { 4, &TriCoreDescs.OperandInfo[335] },  // Inst #1032 = MUL_Q_rr1_2_Ue
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #1031 = MUL_Q_rr1_2_U
  { 4, &TriCoreDescs.OperandInfo[335] },  // Inst #1030 = MUL_Q_rr1_2_Le
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #1029 = MUL_Q_rr1_2_L
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #1028 = MUL_Q_rr1_2UU
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #1027 = MUL_Q_rr1_2LL
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #1026 = MUL_Q_rr1_2
  { 4, &TriCoreDescs.OperandInfo[335] },  // Inst #1025 = MUL_H_rr_v110
  { 4, &TriCoreDescs.OperandInfo[335] },  // Inst #1024 = MUL_H_rr1_UU2e
  { 4, &TriCoreDescs.OperandInfo[335] },  // Inst #1023 = MUL_H_rr1_UL2e
  { 4, &TriCoreDescs.OperandInfo[335] },  // Inst #1022 = MUL_H_rr1_LU2e
  { 4, &TriCoreDescs.OperandInfo[335] },  // Inst #1021 = MUL_H_rr1_LL2e
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1020 = MUL_F_rrr
  { 3, &TriCoreDescs.OperandInfo[229] },  // Inst #1019 = MUL_DF_rrr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1018 = MULS_rr_v110
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1017 = MULS_rr2
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1016 = MULS_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1015 = MULS_U_rr_v110
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #1014 = MULS_U_rr2
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #1013 = MULS_U_rc
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #1012 = MULR_Q_rr_v110
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #1011 = MULR_Q_rr1_2UU
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #1010 = MULR_Q_rr1_2LL
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #1009 = MULR_H_rr_v110
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #1008 = MULR_H_rr1_UU2e
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #1007 = MULR_H_rr1_UL2e
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #1006 = MULR_H_rr1_LU2e
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #1005 = MULR_H_rr1_LL2e
  { 3, &TriCoreDescs.OperandInfo[232] },  // Inst #1004 = MULM_rr
  { 3, &TriCoreDescs.OperandInfo[339] },  // Inst #1003 = MULM_rc
  { 3, &TriCoreDescs.OperandInfo[232] },  // Inst #1002 = MULM_U_rr
  { 3, &TriCoreDescs.OperandInfo[339] },  // Inst #1001 = MULM_U_rc
  { 4, &TriCoreDescs.OperandInfo[335] },  // Inst #1000 = MULM_H_rr1_UU2e
  { 4, &TriCoreDescs.OperandInfo[335] },  // Inst #999 = MULM_H_rr1_UL2e
  { 4, &TriCoreDescs.OperandInfo[335] },  // Inst #998 = MULM_H_rr1_LU2e
  { 4, &TriCoreDescs.OperandInfo[335] },  // Inst #997 = MULM_H_rr1_LL2e
  { 4, &TriCoreDescs.OperandInfo[335] },  // Inst #996 = MULMS_H_rr1_UU2e
  { 4, &TriCoreDescs.OperandInfo[335] },  // Inst #995 = MULMS_H_rr1_UL2e
  { 4, &TriCoreDescs.OperandInfo[335] },  // Inst #994 = MULMS_H_rr1_LU2e
  { 4, &TriCoreDescs.OperandInfo[335] },  // Inst #993 = MULMS_H_rr1_LL2e
  { 2, &TriCoreDescs.OperandInfo[333] },  // Inst #992 = MTCR_rlc
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #991 = MSUB_rrr2_e
  { 4, &TriCoreDescs.OperandInfo[181] },  // Inst #990 = MSUB_rrr2
  { 4, &TriCoreDescs.OperandInfo[314] },  // Inst #989 = MSUB_rcr_e
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #988 = MSUB_rcr
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #987 = MSUB_U_rrr2
  { 4, &TriCoreDescs.OperandInfo[314] },  // Inst #986 = MSUB_U_rcr
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #985 = MSUB_Q_rrr1_e_U_U
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #984 = MSUB_Q_rrr1_e_U
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #983 = MSUB_Q_rrr1_e_L_L
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #982 = MSUB_Q_rrr1_e_L
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #981 = MSUB_Q_rrr1_e
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #980 = MSUB_Q_rrr1_U_U
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #979 = MSUB_Q_rrr1_UU2_v110
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #978 = MSUB_Q_rrr1_U
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #977 = MSUB_Q_rrr1_L_L
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #976 = MSUB_Q_rrr1_L
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #975 = MSUB_Q_rrr1
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #974 = MSUB_H_rrr1_v110
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #973 = MSUB_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #972 = MSUB_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #971 = MSUB_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #970 = MSUB_H_rrr1_LL
  { 4, &TriCoreDescs.OperandInfo[181] },  // Inst #969 = MSUB_F_rrr
  { 4, &TriCoreDescs.OperandInfo[177] },  // Inst #968 = MSUB_DF_rrr
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #967 = MSUBS_rrr2_e
  { 4, &TriCoreDescs.OperandInfo[181] },  // Inst #966 = MSUBS_rrr2
  { 4, &TriCoreDescs.OperandInfo[314] },  // Inst #965 = MSUBS_rcr_e
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #964 = MSUBS_rcr
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #963 = MSUBS_U_rrr2_e
  { 4, &TriCoreDescs.OperandInfo[181] },  // Inst #962 = MSUBS_U_rrr2
  { 4, &TriCoreDescs.OperandInfo[314] },  // Inst #961 = MSUBS_U_rcr_e
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #960 = MSUBS_U_rcr
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #959 = MSUBS_Q_rrr1_e_U_U
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #958 = MSUBS_Q_rrr1_e_U
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #957 = MSUBS_Q_rrr1_e_L_L
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #956 = MSUBS_Q_rrr1_e_L
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #955 = MSUBS_Q_rrr1_e
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #954 = MSUBS_Q_rrr1_U_U
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #953 = MSUBS_Q_rrr1_UU2_v110
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #952 = MSUBS_Q_rrr1_U
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #951 = MSUBS_Q_rrr1_L_L
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #950 = MSUBS_Q_rrr1_L
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #949 = MSUBS_Q_rrr1
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #948 = MSUBS_H_rrr1_v110
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #947 = MSUBS_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #946 = MSUBS_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #945 = MSUBS_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #944 = MSUBS_H_rrr1_LL
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #943 = MSUBR_Q_rrr1_v110
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #942 = MSUBR_Q_rrr1_U_U
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #941 = MSUBR_Q_rrr1_L_L
  { 5, &TriCoreDescs.OperandInfo[323] },  // Inst #940 = MSUBR_H_rrr1_v110
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #939 = MSUBR_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[323] },  // Inst #938 = MSUBR_H_rrr1_UL_2
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #937 = MSUBR_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #936 = MSUBR_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #935 = MSUBR_H_rrr1_LL
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #934 = MSUBRS_Q_rrr1_v110
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #933 = MSUBRS_Q_rrr1_U_U
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #932 = MSUBRS_Q_rrr1_L_L
  { 5, &TriCoreDescs.OperandInfo[323] },  // Inst #931 = MSUBRS_H_rrr1_v110
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #930 = MSUBRS_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[323] },  // Inst #929 = MSUBRS_H_rrr1_UL_2
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #928 = MSUBRS_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #927 = MSUBRS_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #926 = MSUBRS_H_rrr1_LL
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #925 = MSUBM_rrr2v110
  { 4, &TriCoreDescs.OperandInfo[314] },  // Inst #924 = MSUBM_rcrv110
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #923 = MSUBM_U_rrr2v110
  { 4, &TriCoreDescs.OperandInfo[314] },  // Inst #922 = MSUBM_U_rcrv110
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #921 = MSUBM_Q_rrr1_v110
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #920 = MSUBM_H_rrr1_v110
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #919 = MSUBM_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #918 = MSUBM_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #917 = MSUBM_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #916 = MSUBM_H_rrr1_LL
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #915 = MSUBMS_rrr2v110
  { 4, &TriCoreDescs.OperandInfo[314] },  // Inst #914 = MSUBMS_rcrv110
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #913 = MSUBMS_U_rrr2v110
  { 4, &TriCoreDescs.OperandInfo[314] },  // Inst #912 = MSUBMS_U_rcrv110
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #911 = MSUBMS_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #910 = MSUBMS_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #909 = MSUBMS_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #908 = MSUBMS_H_rrr1_LL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #907 = MSUBAD_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #906 = MSUBAD_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #905 = MSUBAD_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #904 = MSUBAD_H_rrr1_LL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #903 = MSUBADS_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #902 = MSUBADS_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #901 = MSUBADS_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #900 = MSUBADS_H_rrr1_LL
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #899 = MSUBADR_H_rrr1_v110
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #898 = MSUBADR_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #897 = MSUBADR_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #896 = MSUBADR_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #895 = MSUBADR_H_rrr1_LL
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #894 = MSUBADRS_H_rrr1_v110
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #893 = MSUBADRS_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #892 = MSUBADRS_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #891 = MSUBADRS_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #890 = MSUBADRS_H_rrr1_LL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #889 = MSUBADM_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #888 = MSUBADM_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #887 = MSUBADM_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #886 = MSUBADM_H_rrr1_LL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #885 = MSUBADMS_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #884 = MSUBADMS_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #883 = MSUBADMS_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #882 = MSUBADMS_H_rrr1_LL
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #881 = MOV_srr
  { 2, &TriCoreDescs.OperandInfo[286] },  // Inst #880 = MOV_src_e
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #879 = MOV_src
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #878 = MOV_sc_v110
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #877 = MOV_sc
  { 3, &TriCoreDescs.OperandInfo[232] },  // Inst #876 = MOV_rr_eab
  { 3, &TriCoreDescs.OperandInfo[232] },  // Inst #875 = MOV_rr_e
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #874 = MOV_rr
  { 2, &TriCoreDescs.OperandInfo[286] },  // Inst #873 = MOV_rlc_e
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #872 = MOV_rlc
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #871 = MOV_U_rlc
  { 2, &TriCoreDescs.OperandInfo[239] },  // Inst #870 = MOV_D_srr_srr_v110
  { 2, &TriCoreDescs.OperandInfo[239] },  // Inst #869 = MOV_D_srr_srr
  { 3, &TriCoreDescs.OperandInfo[241] },  // Inst #868 = MOV_D_rr
  { 2, &TriCoreDescs.OperandInfo[331] },  // Inst #867 = MOV_A_srr_v110
  { 2, &TriCoreDescs.OperandInfo[331] },  // Inst #866 = MOV_A_srr
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #865 = MOV_A_src
  { 3, &TriCoreDescs.OperandInfo[328] },  // Inst #864 = MOV_A_rr
  { 2, &TriCoreDescs.OperandInfo[175] },  // Inst #863 = MOV_AA_srr_srr_v110
  { 2, &TriCoreDescs.OperandInfo[175] },  // Inst #862 = MOV_AA_srr_srr
  { 3, &TriCoreDescs.OperandInfo[170] },  // Inst #861 = MOV_AA_rr
  { 1, &TriCoreDescs.OperandInfo[205] },  // Inst #860 = MOVZ_A_sr
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #859 = MOVH_rlc
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #858 = MOVH_A_rlc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #857 = MIN_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #856 = MIN_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #855 = MIN_U_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #854 = MIN_U_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #853 = MIN_HU
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #852 = MIN_H
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #851 = MIN_F_rr
  { 3, &TriCoreDescs.OperandInfo[229] },  // Inst #850 = MIN_DF_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #849 = MIN_BU
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #848 = MIN_B
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #847 = MFCR_rlc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #846 = MAX_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #845 = MAX_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #844 = MAX_U_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #843 = MAX_U_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #842 = MAX_HU
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #841 = MAX_H
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #840 = MAX_F_rr
  { 3, &TriCoreDescs.OperandInfo[229] },  // Inst #839 = MAX_DF_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #838 = MAX_BU
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #837 = MAX_B
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #836 = MADD_rrr2_e
  { 4, &TriCoreDescs.OperandInfo[181] },  // Inst #835 = MADD_rrr2
  { 4, &TriCoreDescs.OperandInfo[314] },  // Inst #834 = MADD_rcr_e
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #833 = MADD_rcr
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #832 = MADD_U_rrr2
  { 4, &TriCoreDescs.OperandInfo[314] },  // Inst #831 = MADD_U_rcr
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #830 = MADD_Q_rrr1_e_U_U
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #829 = MADD_Q_rrr1_e_U
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #828 = MADD_Q_rrr1_e_L_L
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #827 = MADD_Q_rrr1_e_L
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #826 = MADD_Q_rrr1_e
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #825 = MADD_Q_rrr1_U_U
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #824 = MADD_Q_rrr1_UU2_v110
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #823 = MADD_Q_rrr1_U
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #822 = MADD_Q_rrr1_L_L
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #821 = MADD_Q_rrr1_L
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #820 = MADD_Q_rrr1
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #819 = MADD_H_rrr1_v110
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #818 = MADD_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #817 = MADD_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #816 = MADD_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #815 = MADD_H_rrr1_LL
  { 4, &TriCoreDescs.OperandInfo[181] },  // Inst #814 = MADD_F_rrr
  { 4, &TriCoreDescs.OperandInfo[177] },  // Inst #813 = MADD_DF_rrr
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #812 = MADDS_rrr2_e
  { 4, &TriCoreDescs.OperandInfo[181] },  // Inst #811 = MADDS_rrr2
  { 4, &TriCoreDescs.OperandInfo[314] },  // Inst #810 = MADDS_rcr_e
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #809 = MADDS_rcr
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #808 = MADDS_U_rrr2_e
  { 4, &TriCoreDescs.OperandInfo[181] },  // Inst #807 = MADDS_U_rrr2
  { 4, &TriCoreDescs.OperandInfo[314] },  // Inst #806 = MADDS_U_rcr_e
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #805 = MADDS_U_rcr
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #804 = MADDS_Q_rrr1_e_U_U
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #803 = MADDS_Q_rrr1_e_U
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #802 = MADDS_Q_rrr1_e_L_L
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #801 = MADDS_Q_rrr1_e_L
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #800 = MADDS_Q_rrr1_e
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #799 = MADDS_Q_rrr1_U_U
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #798 = MADDS_Q_rrr1_UU2_v110
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #797 = MADDS_Q_rrr1_U
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #796 = MADDS_Q_rrr1_L_L
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #795 = MADDS_Q_rrr1_L
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #794 = MADDS_Q_rrr1
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #793 = MADDS_H_rrr1_v110
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #792 = MADDS_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #791 = MADDS_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #790 = MADDS_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #789 = MADDS_H_rrr1_LL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #788 = MADDSU_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #787 = MADDSU_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #786 = MADDSU_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #785 = MADDSU_H_rrr1_LL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #784 = MADDSUS_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #783 = MADDSUS_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #782 = MADDSUS_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #781 = MADDSUS_H_rrr1_LL
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #780 = MADDSUR_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #779 = MADDSUR_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #778 = MADDSUR_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #777 = MADDSUR_H_rrr1_LL
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #776 = MADDSURS_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #775 = MADDSURS_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #774 = MADDSURS_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #773 = MADDSURS_H_rrr1_LL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #772 = MADDSUM_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #771 = MADDSUM_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #770 = MADDSUM_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #769 = MADDSUM_H_rrr1_LL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #768 = MADDSUMS_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #767 = MADDSUMS_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #766 = MADDSUMS_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #765 = MADDSUMS_H_rrr1_LL
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #764 = MADDR_Q_rrr1_v110
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #763 = MADDR_Q_rrr1_U_U
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #762 = MADDR_Q_rrr1_L_L
  { 5, &TriCoreDescs.OperandInfo[323] },  // Inst #761 = MADDR_H_rrr1_v110
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #760 = MADDR_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[323] },  // Inst #759 = MADDR_H_rrr1_UL_2
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #758 = MADDR_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #757 = MADDR_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #756 = MADDR_H_rrr1_LL
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #755 = MADDRS_Q_rrr1_v110
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #754 = MADDRS_Q_rrr1_U_U
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #753 = MADDRS_Q_rrr1_L_L
  { 5, &TriCoreDescs.OperandInfo[323] },  // Inst #752 = MADDRS_H_rrr1_v110
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #751 = MADDRS_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[323] },  // Inst #750 = MADDRS_H_rrr1_UL_2
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #749 = MADDRS_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #748 = MADDRS_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[318] },  // Inst #747 = MADDRS_H_rrr1_LL
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #746 = MADDM_rrr2_v110
  { 4, &TriCoreDescs.OperandInfo[314] },  // Inst #745 = MADDM_rcr_v110
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #744 = MADDM_U_rrr2_v110
  { 4, &TriCoreDescs.OperandInfo[314] },  // Inst #743 = MADDM_U_rcr_v110
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #742 = MADDM_Q_rrr1_v110
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #741 = MADDM_H_rrr1_v110
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #740 = MADDM_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #739 = MADDM_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #738 = MADDM_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #737 = MADDM_H_rrr1_LL
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #736 = MADDMS_rrr2_v110
  { 4, &TriCoreDescs.OperandInfo[314] },  // Inst #735 = MADDMS_rcr_v110
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #734 = MADDMS_U_rrr2_v110
  { 4, &TriCoreDescs.OperandInfo[314] },  // Inst #733 = MADDMS_U_rcr_v110
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #732 = MADDMS_H_rrr1_UU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #731 = MADDMS_H_rrr1_UL
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #730 = MADDMS_H_rrr1_LU
  { 5, &TriCoreDescs.OperandInfo[309] },  // Inst #729 = MADDMS_H_rrr1_LL
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #728 = LT_srr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #727 = LT_src
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #726 = LT_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #725 = LT_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #724 = LT_WU
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #723 = LT_W
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #722 = LT_U_srrv110
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #721 = LT_U_srcv110
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #720 = LT_U_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #719 = LT_U_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #718 = LT_HU
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #717 = LT_H
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #716 = LT_BU
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #715 = LT_B
  { 3, &TriCoreDescs.OperandInfo[241] },  // Inst #714 = LT_A_rr
  { 2, &TriCoreDescs.OperandInfo[148] },  // Inst #713 = LTODF_rr
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #712 = LOOP_sbr
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #711 = LOOP_brr
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #710 = LOOPU_brr
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #709 = LHA_abs
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #708 = LEA_bol
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #707 = LEA_bo_bso
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #706 = LEA_abs
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #705 = LD_W_sro_v110
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #704 = LD_W_sro
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #703 = LD_W_slro_v110
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #702 = LD_W_slro
  { 2, &TriCoreDescs.OperandInfo[239] },  // Inst #701 = LD_W_slr_v110
  { 2, &TriCoreDescs.OperandInfo[239] },  // Inst #700 = LD_W_slr_post_v110
  { 2, &TriCoreDescs.OperandInfo[239] },  // Inst #699 = LD_W_slr_post
  { 2, &TriCoreDescs.OperandInfo[239] },  // Inst #698 = LD_W_slr
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #697 = LD_W_sc
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #696 = LD_W_bol
  { 2, &TriCoreDescs.OperandInfo[299] },  // Inst #695 = LD_W_bo_r
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #694 = LD_W_bo_pre
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #693 = LD_W_bo_pos
  { 3, &TriCoreDescs.OperandInfo[296] },  // Inst #692 = LD_W_bo_c
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #691 = LD_W_bo_bso
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #690 = LD_W_abs
  { 2, &TriCoreDescs.OperandInfo[299] },  // Inst #689 = LD_Q_bo_r
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #688 = LD_Q_bo_pre
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #687 = LD_Q_bo_pos
  { 3, &TriCoreDescs.OperandInfo[296] },  // Inst #686 = LD_Q_bo_c
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #685 = LD_Q_bo_bso
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #684 = LD_Q_abs
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #683 = LD_H_sro_v110
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #682 = LD_H_sro
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #681 = LD_H_slro_v110
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #680 = LD_H_slro
  { 2, &TriCoreDescs.OperandInfo[239] },  // Inst #679 = LD_H_slr_v110
  { 2, &TriCoreDescs.OperandInfo[239] },  // Inst #678 = LD_H_slr_post_v110
  { 2, &TriCoreDescs.OperandInfo[239] },  // Inst #677 = LD_H_slr_post
  { 2, &TriCoreDescs.OperandInfo[239] },  // Inst #676 = LD_H_slr
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #675 = LD_H_bol
  { 2, &TriCoreDescs.OperandInfo[299] },  // Inst #674 = LD_H_bo_r
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #673 = LD_H_bo_pre
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #672 = LD_H_bo_pos
  { 3, &TriCoreDescs.OperandInfo[296] },  // Inst #671 = LD_H_bo_c
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #670 = LD_H_bo_bso
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #669 = LD_H_abs
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #668 = LD_HU_bol
  { 2, &TriCoreDescs.OperandInfo[299] },  // Inst #667 = LD_HU_bo_r
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #666 = LD_HU_bo_pre
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #665 = LD_HU_bo_pos
  { 3, &TriCoreDescs.OperandInfo[296] },  // Inst #664 = LD_HU_bo_c
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #663 = LD_HU_bo_bso
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #662 = LD_HU_abs
  { 2, &TriCoreDescs.OperandInfo[212] },  // Inst #661 = LD_D_bo_r
  { 3, &TriCoreDescs.OperandInfo[206] },  // Inst #660 = LD_D_bo_pre
  { 3, &TriCoreDescs.OperandInfo[206] },  // Inst #659 = LD_D_bo_pos
  { 3, &TriCoreDescs.OperandInfo[209] },  // Inst #658 = LD_D_bo_c
  { 3, &TriCoreDescs.OperandInfo[206] },  // Inst #657 = LD_D_bo_bso
  { 2, &TriCoreDescs.OperandInfo[286] },  // Inst #656 = LD_D_abs
  { 2, &TriCoreDescs.OperandInfo[307] },  // Inst #655 = LD_DA_bo_r
  { 3, &TriCoreDescs.OperandInfo[301] },  // Inst #654 = LD_DA_bo_pre
  { 3, &TriCoreDescs.OperandInfo[301] },  // Inst #653 = LD_DA_bo_pos
  { 3, &TriCoreDescs.OperandInfo[304] },  // Inst #652 = LD_DA_bo_c
  { 3, &TriCoreDescs.OperandInfo[301] },  // Inst #651 = LD_DA_bo_bso
  { 2, &TriCoreDescs.OperandInfo[194] },  // Inst #650 = LD_DA_abs
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #649 = LD_B_sro_v110
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #648 = LD_B_slro_v110
  { 2, &TriCoreDescs.OperandInfo[239] },  // Inst #647 = LD_B_slr_v110
  { 2, &TriCoreDescs.OperandInfo[239] },  // Inst #646 = LD_B_slr_post_v110
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #645 = LD_B_bol
  { 2, &TriCoreDescs.OperandInfo[299] },  // Inst #644 = LD_B_bo_r
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #643 = LD_B_bo_pre
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #642 = LD_B_bo_pos
  { 3, &TriCoreDescs.OperandInfo[296] },  // Inst #641 = LD_B_bo_c
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #640 = LD_B_bo_bso
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #639 = LD_B_abs
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #638 = LD_BU_sro_v110
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #637 = LD_BU_sro
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #636 = LD_BU_slro_v110
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #635 = LD_BU_slro
  { 2, &TriCoreDescs.OperandInfo[239] },  // Inst #634 = LD_BU_slr_v110
  { 2, &TriCoreDescs.OperandInfo[239] },  // Inst #633 = LD_BU_slr_post_v110
  { 2, &TriCoreDescs.OperandInfo[239] },  // Inst #632 = LD_BU_slr_post
  { 2, &TriCoreDescs.OperandInfo[239] },  // Inst #631 = LD_BU_slr
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #630 = LD_BU_bol
  { 2, &TriCoreDescs.OperandInfo[299] },  // Inst #629 = LD_BU_bo_r
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #628 = LD_BU_bo_pre
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #627 = LD_BU_bo_pos
  { 3, &TriCoreDescs.OperandInfo[296] },  // Inst #626 = LD_BU_bo_c
  { 3, &TriCoreDescs.OperandInfo[293] },  // Inst #625 = LD_BU_bo_bso
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #624 = LD_BU_abs
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #623 = LD_A_sro_v110
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #622 = LD_A_sro
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #621 = LD_A_slro_v110
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #620 = LD_A_slro
  { 2, &TriCoreDescs.OperandInfo[175] },  // Inst #619 = LD_A_slr_v110
  { 2, &TriCoreDescs.OperandInfo[175] },  // Inst #618 = LD_A_slr_post_v110
  { 2, &TriCoreDescs.OperandInfo[175] },  // Inst #617 = LD_A_slr_post
  { 2, &TriCoreDescs.OperandInfo[175] },  // Inst #616 = LD_A_slr
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #615 = LD_A_sc
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #614 = LD_A_bol
  { 2, &TriCoreDescs.OperandInfo[291] },  // Inst #613 = LD_A_bo_r
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #612 = LD_A_bo_pre
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #611 = LD_A_bo_pos
  { 3, &TriCoreDescs.OperandInfo[288] },  // Inst #610 = LD_A_bo_c
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #609 = LD_A_bo_bso
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #608 = LD_A_abs
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #607 = LDUCX_bo_bso
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #606 = LDUCX_abs
  { 2, &TriCoreDescs.OperandInfo[212] },  // Inst #605 = LDMST_bo_r
  { 3, &TriCoreDescs.OperandInfo[206] },  // Inst #604 = LDMST_bo_pre
  { 3, &TriCoreDescs.OperandInfo[206] },  // Inst #603 = LDMST_bo_pos
  { 3, &TriCoreDescs.OperandInfo[209] },  // Inst #602 = LDMST_bo_c
  { 3, &TriCoreDescs.OperandInfo[206] },  // Inst #601 = LDMST_bo_bso
  { 2, &TriCoreDescs.OperandInfo[286] },  // Inst #600 = LDMST_abs
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #599 = LDLCX_bo_bso
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #598 = LDLCX_abs
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #597 = J_sb_v110
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #596 = J_sb
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #595 = J_b
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #594 = JZ_sbr_v110
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #593 = JZ_sbr
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #592 = JZ_sb_v110
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #591 = JZ_sb
  { 3, &TriCoreDescs.OperandInfo[283] },  // Inst #590 = JZ_T_sbrn_v110
  { 3, &TriCoreDescs.OperandInfo[283] },  // Inst #589 = JZ_T_sbrn
  { 3, &TriCoreDescs.OperandInfo[283] },  // Inst #588 = JZ_T_brn
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #587 = JZ_A_sbr
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #586 = JZ_A_brr
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #585 = JNZ_sbr_v110
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #584 = JNZ_sbr
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #583 = JNZ_sb_v110
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #582 = JNZ_sb
  { 3, &TriCoreDescs.OperandInfo[283] },  // Inst #581 = JNZ_T_sbrn_v110
  { 3, &TriCoreDescs.OperandInfo[283] },  // Inst #580 = JNZ_T_sbrn
  { 3, &TriCoreDescs.OperandInfo[283] },  // Inst #579 = JNZ_T_brn
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #578 = JNZ_A_sbr
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #577 = JNZ_A_brr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #576 = JNE_sbr_v110
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #575 = JNE_sbr2
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #574 = JNE_sbr1
  { 3, &TriCoreDescs.OperandInfo[280] },  // Inst #573 = JNE_sbc_v110
  { 3, &TriCoreDescs.OperandInfo[280] },  // Inst #572 = JNE_sbc2
  { 3, &TriCoreDescs.OperandInfo[280] },  // Inst #571 = JNE_sbc1
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #570 = JNE_brr
  { 3, &TriCoreDescs.OperandInfo[280] },  // Inst #569 = JNE_brc
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #568 = JNE_A_brr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #567 = JNEI_brr
  { 3, &TriCoreDescs.OperandInfo[280] },  // Inst #566 = JNEI_brc
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #565 = JNED_brr
  { 3, &TriCoreDescs.OperandInfo[280] },  // Inst #564 = JNED_brc
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #563 = JL_b
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #562 = JLT_brr
  { 3, &TriCoreDescs.OperandInfo[280] },  // Inst #561 = JLT_brc
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #560 = JLT_U_brr
  { 3, &TriCoreDescs.OperandInfo[280] },  // Inst #559 = JLT_U_brc
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #558 = JLTZ_sbr_v110
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #557 = JLTZ_sbr
  { 1, &TriCoreDescs.OperandInfo[205] },  // Inst #556 = JLI_rr_v110
  { 1, &TriCoreDescs.OperandInfo[205] },  // Inst #555 = JLI_rr
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #554 = JLEZ_sbr_v110
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #553 = JLEZ_sbr
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #552 = JLA_b
  { 1, &TriCoreDescs.OperandInfo[205] },  // Inst #551 = JI_sr
  { 1, &TriCoreDescs.OperandInfo[205] },  // Inst #550 = JI_sbr_v110
  { 1, &TriCoreDescs.OperandInfo[205] },  // Inst #549 = JI_rr_v110
  { 1, &TriCoreDescs.OperandInfo[205] },  // Inst #548 = JI_rr
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #547 = JGTZ_sbr_v110
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #546 = JGTZ_sbr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #545 = JGE_brr
  { 3, &TriCoreDescs.OperandInfo[280] },  // Inst #544 = JGE_brc
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #543 = JGE_U_brr
  { 3, &TriCoreDescs.OperandInfo[280] },  // Inst #542 = JGE_U_brc
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #541 = JGEZ_sbr_v110
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #540 = JGEZ_sbr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #539 = JEQ_sbr_v110
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #538 = JEQ_sbr2
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #537 = JEQ_sbr1
  { 3, &TriCoreDescs.OperandInfo[280] },  // Inst #536 = JEQ_sbc_v110
  { 3, &TriCoreDescs.OperandInfo[280] },  // Inst #535 = JEQ_sbc2
  { 3, &TriCoreDescs.OperandInfo[280] },  // Inst #534 = JEQ_sbc1
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #533 = JEQ_brr
  { 3, &TriCoreDescs.OperandInfo[280] },  // Inst #532 = JEQ_brc
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #531 = JEQ_A_brr
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #530 = JA_b
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #529 = IXMIN_rrr
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #528 = IXMIN_U_rrr
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #527 = IXMAX_rrr
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #526 = IXMAX_U_rrr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #525 = ITOF_rr
  { 2, &TriCoreDescs.OperandInfo[192] },  // Inst #524 = ITODF_rr
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #523 = ISYNC_sys
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #522 = INS_T
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #521 = INSN_T
  { 5, &TriCoreDescs.OperandInfo[247] },  // Inst #520 = INSERT_rrrw
  { 4, &TriCoreDescs.OperandInfo[276] },  // Inst #519 = INSERT_rrrr
  { 5, &TriCoreDescs.OperandInfo[217] },  // Inst #518 = INSERT_rrpw
  { 5, &TriCoreDescs.OperandInfo[217] },  // Inst #517 = INSERT_rcrw
  { 4, &TriCoreDescs.OperandInfo[272] },  // Inst #516 = INSERT_rcrr
  { 5, &TriCoreDescs.OperandInfo[267] },  // Inst #515 = INSERT_rcpw
  { 5, &TriCoreDescs.OperandInfo[262] },  // Inst #514 = IMASK_rrrw
  { 5, &TriCoreDescs.OperandInfo[257] },  // Inst #513 = IMASK_rrpw
  { 5, &TriCoreDescs.OperandInfo[257] },  // Inst #512 = IMASK_rcrw
  { 5, &TriCoreDescs.OperandInfo[252] },  // Inst #511 = IMASK_rcpw
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #510 = HPTOF_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #509 = GE_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #508 = GE_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #507 = GE_U_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #506 = GE_U_rc
  { 3, &TriCoreDescs.OperandInfo[241] },  // Inst #505 = GE_A_rr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #504 = FTOU_rr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #503 = FTOUZ_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #502 = FTOQ31_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #501 = FTOQ31Z_rr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #500 = FTOI_rr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #499 = FTOIZ_rr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #498 = FTOIN_rr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #497 = FTOHP_rr
  { 2, &TriCoreDescs.OperandInfo[192] },  // Inst #496 = FTODF_rr
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #495 = FRET_sys
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #494 = FRET_sr
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #493 = FCALL_b
  { 1, &TriCoreDescs.OperandInfo[205] },  // Inst #492 = FCALLA_i
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #491 = FCALLA_b
  { 5, &TriCoreDescs.OperandInfo[247] },  // Inst #490 = EXTR_rrrw
  { 3, &TriCoreDescs.OperandInfo[244] },  // Inst #489 = EXTR_rrrr
  { 5, &TriCoreDescs.OperandInfo[217] },  // Inst #488 = EXTR_rrpw
  { 5, &TriCoreDescs.OperandInfo[247] },  // Inst #487 = EXTR_U_rrrw
  { 3, &TriCoreDescs.OperandInfo[244] },  // Inst #486 = EXTR_U_rrrr
  { 5, &TriCoreDescs.OperandInfo[217] },  // Inst #485 = EXTR_U_rrpw
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #484 = EQ_srr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #483 = EQ_src
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #482 = EQ_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #481 = EQ_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #480 = EQ_W_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #479 = EQ_H_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #478 = EQ_B_rr
  { 3, &TriCoreDescs.OperandInfo[241] },  // Inst #477 = EQ_A_rr
  { 2, &TriCoreDescs.OperandInfo[239] },  // Inst #476 = EQZ_A_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #475 = EQANY_H_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #474 = EQANY_H_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #473 = EQANY_B_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #472 = EQANY_B_rc
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #471 = ENABLE_sys
  { 2, &TriCoreDescs.OperandInfo[192] },  // Inst #470 = DVSTEPv110
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #469 = DVSTEP_rrrv110
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #468 = DVSTEP_rrr
  { 2, &TriCoreDescs.OperandInfo[192] },  // Inst #467 = DVSTEP_Uv110
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #466 = DVSTEP_U_rrrv110
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #465 = DVSTEP_U_rrr
  { 3, &TriCoreDescs.OperandInfo[232] },  // Inst #464 = DVINIT_rr_v110
  { 3, &TriCoreDescs.OperandInfo[232] },  // Inst #463 = DVINIT_rr
  { 3, &TriCoreDescs.OperandInfo[232] },  // Inst #462 = DVINIT_U_rr_v110
  { 3, &TriCoreDescs.OperandInfo[232] },  // Inst #461 = DVINIT_U_rr
  { 3, &TriCoreDescs.OperandInfo[232] },  // Inst #460 = DVINIT_H_rr_v110
  { 3, &TriCoreDescs.OperandInfo[232] },  // Inst #459 = DVINIT_H_rr
  { 3, &TriCoreDescs.OperandInfo[232] },  // Inst #458 = DVINIT_HU_rr_v110
  { 3, &TriCoreDescs.OperandInfo[232] },  // Inst #457 = DVINIT_HU_rr
  { 3, &TriCoreDescs.OperandInfo[232] },  // Inst #456 = DVINIT_B_rr_v110
  { 3, &TriCoreDescs.OperandInfo[232] },  // Inst #455 = DVINIT_B_rr
  { 3, &TriCoreDescs.OperandInfo[232] },  // Inst #454 = DVINIT_BU_rr_v110
  { 3, &TriCoreDescs.OperandInfo[232] },  // Inst #453 = DVINIT_BU_rr
  { 2, &TriCoreDescs.OperandInfo[192] },  // Inst #452 = DVADJ_srr_v110
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #451 = DVADJ_rrr_v110
  { 4, &TriCoreDescs.OperandInfo[235] },  // Inst #450 = DVADJ_rrr
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #449 = DSYNC_sys
  { 3, &TriCoreDescs.OperandInfo[232] },  // Inst #448 = DIV_rr
  { 3, &TriCoreDescs.OperandInfo[232] },  // Inst #447 = DIV_U_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #446 = DIV_F_rr
  { 3, &TriCoreDescs.OperandInfo[229] },  // Inst #445 = DIV_DF_rr
  { 3, &TriCoreDescs.OperandInfo[229] },  // Inst #444 = DIV64_rr
  { 3, &TriCoreDescs.OperandInfo[229] },  // Inst #443 = DIV64_U_rr
  { 1, &TriCoreDescs.OperandInfo[228] },  // Inst #442 = DISABLE_sys_1
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #441 = DISABLE_sys
  { 4, &TriCoreDescs.OperandInfo[224] },  // Inst #440 = DIFSC_A_rr_v110
  { 2, &TriCoreDescs.OperandInfo[222] },  // Inst #439 = DFTOU_rr
  { 2, &TriCoreDescs.OperandInfo[222] },  // Inst #438 = DFTOUZ_rr
  { 2, &TriCoreDescs.OperandInfo[148] },  // Inst #437 = DFTOUL_rr
  { 2, &TriCoreDescs.OperandInfo[148] },  // Inst #436 = DFTOULZ_rr
  { 2, &TriCoreDescs.OperandInfo[148] },  // Inst #435 = DFTOL_rr
  { 2, &TriCoreDescs.OperandInfo[148] },  // Inst #434 = DFTOLZ_rr
  { 2, &TriCoreDescs.OperandInfo[222] },  // Inst #433 = DFTOI_rr
  { 2, &TriCoreDescs.OperandInfo[222] },  // Inst #432 = DFTOIZ_rr
  { 2, &TriCoreDescs.OperandInfo[222] },  // Inst #431 = DFTOIN_rr
  { 2, &TriCoreDescs.OperandInfo[222] },  // Inst #430 = DFTOF_rr
  { 4, &TriCoreDescs.OperandInfo[181] },  // Inst #429 = DEXTR_rrrr
  { 5, &TriCoreDescs.OperandInfo[217] },  // Inst #428 = DEXTR_rrpw
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #427 = DEBUG_sys
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #426 = DEBUG_sr
  { 4, &TriCoreDescs.OperandInfo[181] },  // Inst #425 = CSUB_rrr
  { 4, &TriCoreDescs.OperandInfo[197] },  // Inst #424 = CSUB_A__rrr_v110
  { 4, &TriCoreDescs.OperandInfo[181] },  // Inst #423 = CSUBN_rrr
  { 4, &TriCoreDescs.OperandInfo[197] },  // Inst #422 = CSUBN_A__rrr_v110
  { 4, &TriCoreDescs.OperandInfo[181] },  // Inst #421 = CRCN_rrr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #420 = CRC32_B_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #419 = CRC32L_W_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #418 = CRC32B_W_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #417 = CMP_F_rr
  { 3, &TriCoreDescs.OperandInfo[214] },  // Inst #416 = CMP_DF_rr
  { 2, &TriCoreDescs.OperandInfo[212] },  // Inst #415 = CMPSWAP_W_bo_r
  { 3, &TriCoreDescs.OperandInfo[206] },  // Inst #414 = CMPSWAP_W_bo_pre
  { 3, &TriCoreDescs.OperandInfo[206] },  // Inst #413 = CMPSWAP_W_bo_pos
  { 3, &TriCoreDescs.OperandInfo[209] },  // Inst #412 = CMPSWAP_W_bo_c
  { 3, &TriCoreDescs.OperandInfo[206] },  // Inst #411 = CMPSWAP_W_bo_bso
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #410 = CMOV_srr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #409 = CMOV_src
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #408 = CMOVN_srr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #407 = CMOVN_src
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #406 = CLZ_rr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #405 = CLZ_H_rr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #404 = CLZ_B_rr_v110
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #403 = CLS_rr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #402 = CLS_H_rr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #401 = CLS_B_rr_v110
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #400 = CLO_rr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #399 = CLO_H_rr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #398 = CLO_B_rr_v110
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #397 = CALL_sb
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #396 = CALL_b
  { 1, &TriCoreDescs.OperandInfo[205] },  // Inst #395 = CALLI_rr_v110
  { 1, &TriCoreDescs.OperandInfo[205] },  // Inst #394 = CALLI_rr
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #393 = CALLA_b
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #392 = CADD_srr_v110
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #391 = CADD_src
  { 4, &TriCoreDescs.OperandInfo[181] },  // Inst #390 = CADD_rrr
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #389 = CADD_rcr
  { 4, &TriCoreDescs.OperandInfo[197] },  // Inst #388 = CADD_A_rrr_v110
  { 4, &TriCoreDescs.OperandInfo[163] },  // Inst #387 = CADD_A_rcr_v110
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #386 = CADDN_srr_v110
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #385 = CADDN_src
  { 4, &TriCoreDescs.OperandInfo[181] },  // Inst #384 = CADDN_rrr
  { 4, &TriCoreDescs.OperandInfo[201] },  // Inst #383 = CADDN_rcr
  { 4, &TriCoreDescs.OperandInfo[197] },  // Inst #382 = CADDN_A_rrr_v110
  { 4, &TriCoreDescs.OperandInfo[163] },  // Inst #381 = CADDN_A_rcr_v110
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #380 = CACHEI_W_bo_pre
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #379 = CACHEI_W_bo_pos
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #378 = CACHEI_W_bo_bso
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #377 = CACHEI_WI_bo_pre
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #376 = CACHEI_WI_bo_pos
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #375 = CACHEI_WI_bo_bso
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #374 = CACHEI_I_bo_pre
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #373 = CACHEI_I_bo_pos
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #372 = CACHEI_I_bo_bso
  { 1, &TriCoreDescs.OperandInfo[196] },  // Inst #371 = CACHEA_W_bo_r
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #370 = CACHEA_W_bo_pre
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #369 = CACHEA_W_bo_pos
  { 2, &TriCoreDescs.OperandInfo[194] },  // Inst #368 = CACHEA_W_bo_c
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #367 = CACHEA_W_bo_bso
  { 1, &TriCoreDescs.OperandInfo[196] },  // Inst #366 = CACHEA_WI_bo_r
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #365 = CACHEA_WI_bo_pre
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #364 = CACHEA_WI_bo_pos
  { 2, &TriCoreDescs.OperandInfo[194] },  // Inst #363 = CACHEA_WI_bo_c
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #362 = CACHEA_WI_bo_bso
  { 1, &TriCoreDescs.OperandInfo[196] },  // Inst #361 = CACHEA_I_bo_r
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #360 = CACHEA_I_bo_pre
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #359 = CACHEA_I_bo_pos
  { 2, &TriCoreDescs.OperandInfo[194] },  // Inst #358 = CACHEA_I_bo_c
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #357 = CACHEA_I_bo_bso
  { 2, &TriCoreDescs.OperandInfo[192] },  // Inst #356 = BSPLIT_rr_v110
  { 2, &TriCoreDescs.OperandInfo[192] },  // Inst #355 = BSPLIT_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #354 = BMERGE_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #353 = BMERGAE_rr_v110
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #352 = BISR_sc_v110
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #351 = BISR_sc
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #350 = BISR_rc
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #349 = AND_srr_v110
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #348 = AND_srr
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #347 = AND_sc_v110
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #346 = AND_sc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #345 = AND_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #344 = AND_rc
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #343 = AND_T
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #342 = AND_OR_T
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #341 = AND_NOR_T
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #340 = AND_NE_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #339 = AND_NE_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #338 = AND_LT_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #337 = AND_LT_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #336 = AND_LT_U_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #335 = AND_LT_U_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #334 = AND_GE_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #333 = AND_GE_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #332 = AND_GE_U_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #331 = AND_GE_U_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #330 = AND_EQ_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #329 = AND_EQ_rc
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #328 = AND_AND_T
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #327 = AND_ANDN_T
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #326 = ANDN_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #325 = ANDN_rc
  { 5, &TriCoreDescs.OperandInfo[187] },  // Inst #324 = ANDN_T
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #323 = ADD_srr_a15
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #322 = ADD_srr_15a
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #321 = ADD_srr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #320 = ADD_src_a15
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #319 = ADD_src_15a
  { 2, &TriCoreDescs.OperandInfo[185] },  // Inst #318 = ADD_src
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #317 = ADD_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #316 = ADD_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #315 = ADD_H_rr
  { 4, &TriCoreDescs.OperandInfo[181] },  // Inst #314 = ADD_F_rrr
  { 4, &TriCoreDescs.OperandInfo[177] },  // Inst #313 = ADD_DF_rrr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #312 = ADD_B_rr
  { 2, &TriCoreDescs.OperandInfo[175] },  // Inst #311 = ADD_A_srr
  { 2, &TriCoreDescs.OperandInfo[173] },  // Inst #310 = ADD_A_src
  { 3, &TriCoreDescs.OperandInfo[170] },  // Inst #309 = ADD_A_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #308 = ADDX_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #307 = ADDX_rc
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #306 = ADDS_srr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #305 = ADDS_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #304 = ADDS_rc
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #303 = ADDS_U_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #302 = ADDS_U
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #301 = ADDS_HU
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #300 = ADDS_H
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #299 = ADDS_B_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #298 = ADDS_BU_rr_v110
  { 3, &TriCoreDescs.OperandInfo[167] },  // Inst #297 = ADDSC_A_srrs_v110
  { 4, &TriCoreDescs.OperandInfo[163] },  // Inst #296 = ADDSC_A_srrs
  { 4, &TriCoreDescs.OperandInfo[163] },  // Inst #295 = ADDSC_A_rr_v110
  { 4, &TriCoreDescs.OperandInfo[159] },  // Inst #294 = ADDSC_A_rr
  { 3, &TriCoreDescs.OperandInfo[156] },  // Inst #293 = ADDSC_AT_rr_v110
  { 3, &TriCoreDescs.OperandInfo[153] },  // Inst #292 = ADDSC_AT_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #291 = ADDI_rlc
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #290 = ADDIH_rlc
  { 3, &TriCoreDescs.OperandInfo[150] },  // Inst #289 = ADDIH_A_rlc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #288 = ADDC_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #287 = ADDC_rc
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #286 = ABS_rr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #285 = ABS_H_rr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #284 = ABS_F_rr
  { 2, &TriCoreDescs.OperandInfo[148] },  // Inst #283 = ABS_DF_rr
  { 2, &TriCoreDescs.OperandInfo[146] },  // Inst #282 = ABS_B_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #281 = ABSS_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #280 = ABSS_H_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #279 = ABSS_B_rr_v110
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #278 = ABSDIF_rr
  { 3, &TriCoreDescs.OperandInfo[143] },  // Inst #277 = ABSDIF_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #276 = ABSDIF_H_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #275 = ABSDIF_B_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #274 = ABSDIFS_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #273 = ABSDIFS_rc
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #272 = ABSDIFS_H_rr
  { 3, &TriCoreDescs.OperandInfo[140] },  // Inst #271 = ABSDIFS_B_rr_v110
  { 4, &TriCoreDescs.OperandInfo[136] },  // Inst #270 = G_UBFX
  { 4, &TriCoreDescs.OperandInfo[136] },  // Inst #269 = G_SBFX
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #268 = G_VECREDUCE_UMIN
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #267 = G_VECREDUCE_UMAX
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #266 = G_VECREDUCE_SMIN
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #265 = G_VECREDUCE_SMAX
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #264 = G_VECREDUCE_XOR
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #263 = G_VECREDUCE_OR
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #262 = G_VECREDUCE_AND
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #261 = G_VECREDUCE_MUL
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #260 = G_VECREDUCE_ADD
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #259 = G_VECREDUCE_FMINIMUM
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #258 = G_VECREDUCE_FMAXIMUM
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #257 = G_VECREDUCE_FMIN
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #256 = G_VECREDUCE_FMAX
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #255 = G_VECREDUCE_FMUL
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #254 = G_VECREDUCE_FADD
  { 3, &TriCoreDescs.OperandInfo[123] },  // Inst #253 = G_VECREDUCE_SEQ_FMUL
  { 3, &TriCoreDescs.OperandInfo[123] },  // Inst #252 = G_VECREDUCE_SEQ_FADD
  { 3, &TriCoreDescs.OperandInfo[53] },  // Inst #251 = G_BZERO
  { 4, &TriCoreDescs.OperandInfo[132] },  // Inst #250 = G_MEMSET
  { 4, &TriCoreDescs.OperandInfo[132] },  // Inst #249 = G_MEMMOVE
  { 3, &TriCoreDescs.OperandInfo[123] },  // Inst #248 = G_MEMCPY_INLINE
  { 4, &TriCoreDescs.OperandInfo[132] },  // Inst #247 = G_MEMCPY
  { 2, &TriCoreDescs.OperandInfo[130] },  // Inst #246 = G_WRITE_REGISTER
  { 2, &TriCoreDescs.OperandInfo[51] },  // Inst #245 = G_READ_REGISTER
  { 3, &TriCoreDescs.OperandInfo[96] },  // Inst #244 = G_STRICT_FLDEXP
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #243 = G_STRICT_FSQRT
  { 4, &TriCoreDescs.OperandInfo[46] },  // Inst #242 = G_STRICT_FMA
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #241 = G_STRICT_FREM
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #240 = G_STRICT_FDIV
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #239 = G_STRICT_FMUL
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #238 = G_STRICT_FSUB
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #237 = G_STRICT_FADD
  { 1, &TriCoreDescs.OperandInfo[50] },  // Inst #236 = G_STACKRESTORE
  { 1, &TriCoreDescs.OperandInfo[50] },  // Inst #235 = G_STACKSAVE
  { 3, &TriCoreDescs.OperandInfo[64] },  // Inst #234 = G_DYN_STACKALLOC
  { 2, &TriCoreDescs.OperandInfo[51] },  // Inst #233 = G_JUMP_TABLE
  { 2, &TriCoreDescs.OperandInfo[51] },  // Inst #232 = G_BLOCK_ADDR
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #231 = G_ADDRSPACE_CAST
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #230 = G_FNEARBYINT
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #229 = G_FRINT
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #228 = G_FFLOOR
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #227 = G_FSQRT
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #226 = G_FSIN
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #225 = G_FCOS
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #224 = G_FCEIL
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #223 = G_BITREVERSE
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #222 = G_BSWAP
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #221 = G_CTPOP
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #220 = G_CTLZ_ZERO_UNDEF
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #219 = G_CTLZ
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #218 = G_CTTZ_ZERO_UNDEF
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #217 = G_CTTZ
  { 4, &TriCoreDescs.OperandInfo[126] },  // Inst #216 = G_SHUFFLE_VECTOR
  { 3, &TriCoreDescs.OperandInfo[123] },  // Inst #215 = G_EXTRACT_VECTOR_ELT
  { 4, &TriCoreDescs.OperandInfo[119] },  // Inst #214 = G_INSERT_VECTOR_ELT
  { 3, &TriCoreDescs.OperandInfo[116] },  // Inst #213 = G_BRJT
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #212 = G_BR
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #211 = G_LLROUND
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #210 = G_LROUND
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #209 = G_ABS
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #208 = G_UMAX
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #207 = G_UMIN
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #206 = G_SMAX
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #205 = G_SMIN
  { 3, &TriCoreDescs.OperandInfo[96] },  // Inst #204 = G_PTRMASK
  { 3, &TriCoreDescs.OperandInfo[96] },  // Inst #203 = G_PTR_ADD
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #202 = G_RESET_FPMODE
  { 1, &TriCoreDescs.OperandInfo[50] },  // Inst #201 = G_SET_FPMODE
  { 1, &TriCoreDescs.OperandInfo[50] },  // Inst #200 = G_GET_FPMODE
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #199 = G_RESET_FPENV
  { 1, &TriCoreDescs.OperandInfo[50] },  // Inst #198 = G_SET_FPENV
  { 1, &TriCoreDescs.OperandInfo[50] },  // Inst #197 = G_GET_FPENV
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #196 = G_FMAXIMUM
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #195 = G_FMINIMUM
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #194 = G_FMAXNUM_IEEE
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #193 = G_FMINNUM_IEEE
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #192 = G_FMAXNUM
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #191 = G_FMINNUM
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #190 = G_FCANONICALIZE
  { 3, &TriCoreDescs.OperandInfo[93] },  // Inst #189 = G_IS_FPCLASS
  { 3, &TriCoreDescs.OperandInfo[96] },  // Inst #188 = G_FCOPYSIGN
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #187 = G_FABS
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #186 = G_UITOFP
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #185 = G_SITOFP
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #184 = G_FPTOUI
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #183 = G_FPTOSI
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #182 = G_FPTRUNC
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #181 = G_FPEXT
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #180 = G_FNEG
  { 3, &TriCoreDescs.OperandInfo[86] },  // Inst #179 = G_FFREXP
  { 3, &TriCoreDescs.OperandInfo[96] },  // Inst #178 = G_FLDEXP
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #177 = G_FLOG10
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #176 = G_FLOG2
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #175 = G_FLOG
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #174 = G_FEXP10
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #173 = G_FEXP2
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #172 = G_FEXP
  { 3, &TriCoreDescs.OperandInfo[96] },  // Inst #171 = G_FPOWI
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #170 = G_FPOW
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #169 = G_FREM
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #168 = G_FDIV
  { 4, &TriCoreDescs.OperandInfo[46] },  // Inst #167 = G_FMAD
  { 4, &TriCoreDescs.OperandInfo[46] },  // Inst #166 = G_FMA
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #165 = G_FMUL
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #164 = G_FSUB
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #163 = G_FADD
  { 4, &TriCoreDescs.OperandInfo[112] },  // Inst #162 = G_UDIVFIXSAT
  { 4, &TriCoreDescs.OperandInfo[112] },  // Inst #161 = G_SDIVFIXSAT
  { 4, &TriCoreDescs.OperandInfo[112] },  // Inst #160 = G_UDIVFIX
  { 4, &TriCoreDescs.OperandInfo[112] },  // Inst #159 = G_SDIVFIX
  { 4, &TriCoreDescs.OperandInfo[112] },  // Inst #158 = G_UMULFIXSAT
  { 4, &TriCoreDescs.OperandInfo[112] },  // Inst #157 = G_SMULFIXSAT
  { 4, &TriCoreDescs.OperandInfo[112] },  // Inst #156 = G_UMULFIX
  { 4, &TriCoreDescs.OperandInfo[112] },  // Inst #155 = G_SMULFIX
  { 3, &TriCoreDescs.OperandInfo[96] },  // Inst #154 = G_SSHLSAT
  { 3, &TriCoreDescs.OperandInfo[96] },  // Inst #153 = G_USHLSAT
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #152 = G_SSUBSAT
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #151 = G_USUBSAT
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #150 = G_SADDSAT
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #149 = G_UADDSAT
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #148 = G_SMULH
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #147 = G_UMULH
  { 4, &TriCoreDescs.OperandInfo[82] },  // Inst #146 = G_SMULO
  { 4, &TriCoreDescs.OperandInfo[82] },  // Inst #145 = G_UMULO
  { 5, &TriCoreDescs.OperandInfo[107] },  // Inst #144 = G_SSUBE
  { 4, &TriCoreDescs.OperandInfo[82] },  // Inst #143 = G_SSUBO
  { 5, &TriCoreDescs.OperandInfo[107] },  // Inst #142 = G_SADDE
  { 4, &TriCoreDescs.OperandInfo[82] },  // Inst #141 = G_SADDO
  { 5, &TriCoreDescs.OperandInfo[107] },  // Inst #140 = G_USUBE
  { 4, &TriCoreDescs.OperandInfo[82] },  // Inst #139 = G_USUBO
  { 5, &TriCoreDescs.OperandInfo[107] },  // Inst #138 = G_UADDE
  { 4, &TriCoreDescs.OperandInfo[82] },  // Inst #137 = G_UADDO
  { 4, &TriCoreDescs.OperandInfo[82] },  // Inst #136 = G_SELECT
  { 4, &TriCoreDescs.OperandInfo[103] },  // Inst #135 = G_FCMP
  { 4, &TriCoreDescs.OperandInfo[103] },  // Inst #134 = G_ICMP
  { 3, &TriCoreDescs.OperandInfo[96] },  // Inst #133 = G_ROTL
  { 3, &TriCoreDescs.OperandInfo[96] },  // Inst #132 = G_ROTR
  { 4, &TriCoreDescs.OperandInfo[99] },  // Inst #131 = G_FSHR
  { 4, &TriCoreDescs.OperandInfo[99] },  // Inst #130 = G_FSHL
  { 3, &TriCoreDescs.OperandInfo[96] },  // Inst #129 = G_ASHR
  { 3, &TriCoreDescs.OperandInfo[96] },  // Inst #128 = G_LSHR
  { 3, &TriCoreDescs.OperandInfo[96] },  // Inst #127 = G_SHL
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #126 = G_ZEXT
  { 3, &TriCoreDescs.OperandInfo[40] },  // Inst #125 = G_SEXT_INREG
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #124 = G_SEXT
  { 3, &TriCoreDescs.OperandInfo[93] },  // Inst #123 = G_VAARG
  { 1, &TriCoreDescs.OperandInfo[50] },  // Inst #122 = G_VASTART
  { 2, &TriCoreDescs.OperandInfo[51] },  // Inst #121 = G_FCONSTANT
  { 2, &TriCoreDescs.OperandInfo[51] },  // Inst #120 = G_CONSTANT
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #119 = G_TRUNC
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #118 = G_ANYEXT
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #117 = G_INTRINSIC_CONVERGENT_W_SIDE_EFFECTS
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #116 = G_INTRINSIC_CONVERGENT
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #115 = G_INTRINSIC_W_SIDE_EFFECTS
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #114 = G_INTRINSIC
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #113 = G_INVOKE_REGION_START
  { 1, &TriCoreDescs.OperandInfo[50] },  // Inst #112 = G_BRINDIRECT
  { 2, &TriCoreDescs.OperandInfo[51] },  // Inst #111 = G_BRCOND
  { 4, &TriCoreDescs.OperandInfo[89] },  // Inst #110 = G_PREFETCH
  { 2, &TriCoreDescs.OperandInfo[21] },  // Inst #109 = G_FENCE
  { 3, &TriCoreDescs.OperandInfo[86] },  // Inst #108 = G_ATOMICRMW_UDEC_WRAP
  { 3, &TriCoreDescs.OperandInfo[86] },  // Inst #107 = G_ATOMICRMW_UINC_WRAP
  { 3, &TriCoreDescs.OperandInfo[86] },  // Inst #106 = G_ATOMICRMW_FMIN
  { 3, &TriCoreDescs.OperandInfo[86] },  // Inst #105 = G_ATOMICRMW_FMAX
  { 3, &TriCoreDescs.OperandInfo[86] },  // Inst #104 = G_ATOMICRMW_FSUB
  { 3, &TriCoreDescs.OperandInfo[86] },  // Inst #103 = G_ATOMICRMW_FADD
  { 3, &TriCoreDescs.OperandInfo[86] },  // Inst #102 = G_ATOMICRMW_UMIN
  { 3, &TriCoreDescs.OperandInfo[86] },  // Inst #101 = G_ATOMICRMW_UMAX
  { 3, &TriCoreDescs.OperandInfo[86] },  // Inst #100 = G_ATOMICRMW_MIN
  { 3, &TriCoreDescs.OperandInfo[86] },  // Inst #99 = G_ATOMICRMW_MAX
  { 3, &TriCoreDescs.OperandInfo[86] },  // Inst #98 = G_ATOMICRMW_XOR
  { 3, &TriCoreDescs.OperandInfo[86] },  // Inst #97 = G_ATOMICRMW_OR
  { 3, &TriCoreDescs.OperandInfo[86] },  // Inst #96 = G_ATOMICRMW_NAND
  { 3, &TriCoreDescs.OperandInfo[86] },  // Inst #95 = G_ATOMICRMW_AND
  { 3, &TriCoreDescs.OperandInfo[86] },  // Inst #94 = G_ATOMICRMW_SUB
  { 3, &TriCoreDescs.OperandInfo[86] },  // Inst #93 = G_ATOMICRMW_ADD
  { 3, &TriCoreDescs.OperandInfo[86] },  // Inst #92 = G_ATOMICRMW_XCHG
  { 4, &TriCoreDescs.OperandInfo[82] },  // Inst #91 = G_ATOMIC_CMPXCHG
  { 5, &TriCoreDescs.OperandInfo[77] },  // Inst #90 = G_ATOMIC_CMPXCHG_WITH_SUCCESS
  { 5, &TriCoreDescs.OperandInfo[72] },  // Inst #89 = G_INDEXED_STORE
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #88 = G_STORE
  { 5, &TriCoreDescs.OperandInfo[67] },  // Inst #87 = G_INDEXED_ZEXTLOAD
  { 5, &TriCoreDescs.OperandInfo[67] },  // Inst #86 = G_INDEXED_SEXTLOAD
  { 5, &TriCoreDescs.OperandInfo[67] },  // Inst #85 = G_INDEXED_LOAD
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #84 = G_ZEXTLOAD
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #83 = G_SEXTLOAD
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #82 = G_LOAD
  { 1, &TriCoreDescs.OperandInfo[50] },  // Inst #81 = G_READCYCLECOUNTER
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #80 = G_INTRINSIC_ROUNDEVEN
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #79 = G_INTRINSIC_LRINT
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #78 = G_INTRINSIC_ROUND
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #77 = G_INTRINSIC_TRUNC
  { 3, &TriCoreDescs.OperandInfo[64] },  // Inst #76 = G_INTRINSIC_FPTRUNC_ROUND
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #75 = G_CONSTANT_FOLD_BARRIER
  { 2, &TriCoreDescs.OperandInfo[62] },  // Inst #74 = G_FREEZE
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #73 = G_BITCAST
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #72 = G_INTTOPTR
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #71 = G_PTRTOINT
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #70 = G_CONCAT_VECTORS
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #69 = G_BUILD_VECTOR_TRUNC
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #68 = G_BUILD_VECTOR
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #67 = G_MERGE_VALUES
  { 4, &TriCoreDescs.OperandInfo[58] },  // Inst #66 = G_INSERT
  { 2, &TriCoreDescs.OperandInfo[56] },  // Inst #65 = G_UNMERGE_VALUES
  { 3, &TriCoreDescs.OperandInfo[53] },  // Inst #64 = G_EXTRACT
  { 2, &TriCoreDescs.OperandInfo[51] },  // Inst #63 = G_CONSTANT_POOL
  { 2, &TriCoreDescs.OperandInfo[51] },  // Inst #62 = G_GLOBAL_VALUE
  { 2, &TriCoreDescs.OperandInfo[51] },  // Inst #61 = G_FRAME_INDEX
  { 1, &TriCoreDescs.OperandInfo[50] },  // Inst #60 = G_PHI
  { 1, &TriCoreDescs.OperandInfo[50] },  // Inst #59 = G_IMPLICIT_DEF
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #58 = G_XOR
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #57 = G_OR
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #56 = G_AND
  { 4, &TriCoreDescs.OperandInfo[46] },  // Inst #55 = G_UDIVREM
  { 4, &TriCoreDescs.OperandInfo[46] },  // Inst #54 = G_SDIVREM
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #53 = G_UREM
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #52 = G_SREM
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #51 = G_UDIV
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #50 = G_SDIV
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #49 = G_MUL
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #48 = G_SUB
  { 3, &TriCoreDescs.OperandInfo[43] },  // Inst #47 = G_ADD
  { 3, &TriCoreDescs.OperandInfo[40] },  // Inst #46 = G_ASSERT_ALIGN
  { 3, &TriCoreDescs.OperandInfo[40] },  // Inst #45 = G_ASSERT_ZEXT
  { 3, &TriCoreDescs.OperandInfo[40] },  // Inst #44 = G_ASSERT_SEXT
  { 1, &TriCoreDescs.OperandInfo[1] },  // Inst #43 = JUMP_TABLE_DEBUG_INFO
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #42 = MEMBARRIER
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #41 = ICALL_BRANCH_FUNNEL
  { 3, &TriCoreDescs.OperandInfo[37] },  // Inst #40 = PATCHABLE_TYPED_EVENT_CALL
  { 2, &TriCoreDescs.OperandInfo[35] },  // Inst #39 = PATCHABLE_EVENT_CALL
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #38 = PATCHABLE_TAIL_CALL
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #37 = PATCHABLE_FUNCTION_EXIT
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #36 = PATCHABLE_RET
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #35 = PATCHABLE_FUNCTION_ENTER
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #34 = PATCHABLE_OP
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #33 = FAULTING_OP
  { 2, &TriCoreDescs.OperandInfo[33] },  // Inst #32 = LOCAL_ESCAPE
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #31 = STATEPOINT
  { 3, &TriCoreDescs.OperandInfo[30] },  // Inst #30 = PREALLOCATED_ARG
  { 1, &TriCoreDescs.OperandInfo[1] },  // Inst #29 = PREALLOCATED_SETUP
  { 1, &TriCoreDescs.OperandInfo[29] },  // Inst #28 = LOAD_STACK_GUARD
  { 6, &TriCoreDescs.OperandInfo[23] },  // Inst #27 = PATCHPOINT
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #26 = FENTRY_CALL
  { 2, &TriCoreDescs.OperandInfo[21] },  // Inst #25 = STACKMAP
  { 2, &TriCoreDescs.OperandInfo[19] },  // Inst #24 = ARITH_FENCE
  { 4, &TriCoreDescs.OperandInfo[15] },  // Inst #23 = PSEUDO_PROBE
  { 1, &TriCoreDescs.OperandInfo[1] },  // Inst #22 = LIFETIME_END
  { 1, &TriCoreDescs.OperandInfo[1] },  // Inst #21 = LIFETIME_START
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #20 = BUNDLE
  { 2, &TriCoreDescs.OperandInfo[13] },  // Inst #19 = COPY
  { 2, &TriCoreDescs.OperandInfo[13] },  // Inst #18 = REG_SEQUENCE
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #17 = DBG_LABEL
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #16 = DBG_PHI
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #15 = DBG_INSTR_REF
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #14 = DBG_VALUE_LIST
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #13 = DBG_VALUE
  { 3, &TriCoreDescs.OperandInfo[2] },  // Inst #12 = COPY_TO_REGCLASS
  { 4, &TriCoreDescs.OperandInfo[9] },  // Inst #11 = SUBREG_TO_REG
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #10 = IMPLICIT_DEF
  { 4, &TriCoreDescs.OperandInfo[5] },  // Inst #9 = INSERT_SUBREG
  { 3, &TriCoreDescs.OperandInfo[2] },  // Inst #8 = EXTRACT_SUBREG
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #7 = KILL
  { 1, &TriCoreDescs.OperandInfo[1] },  // Inst #6 = ANNOTATION_LABEL
  { 1, &TriCoreDescs.OperandInfo[1] },  // Inst #5 = GC_LABEL
  { 1, &TriCoreDescs.OperandInfo[1] },  // Inst #4 = EH_LABEL
  { 1, &TriCoreDescs.OperandInfo[1] },  // Inst #3 = CFI_INSTRUCTION
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #2 = INLINEASM_BR
  { 0, &TriCoreDescs.OperandInfo[1] },  // Inst #1 = INLINEASM
  { 1, &TriCoreDescs.OperandInfo[0] },  // Inst #0 = PHI
  }, {
    /* 0 */ { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 1 */
    /* 1 */ { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 },
    /* 2 */ { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 },
    /* 5 */ { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, CONSTRAINT_MCOI_TIED_TO(0) }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 },
    /* 9 */ { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 },
    /* 13 */ { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 15 */ { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 },
    /* 19 */ { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, CONSTRAINT_MCOI_TIED_TO(0) },
    /* 21 */ { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 },
    /* 23 */ { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 },
    /* 29 */ { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 },
    /* 30 */ { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 },
    /* 33 */ { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 },
    /* 35 */ { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 37 */ { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 40 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_IMM_0, 0 },
    /* 43 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 },
    /* 46 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 },
    /* 50 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 },
    /* 51 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 53 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_IMM_0, 0 },
    /* 56 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 },
    /* 58 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_IMM_0, 0 },
    /* 62 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 },
    /* 64 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 },
    /* 67 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_2, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 72 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_2, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 77 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_2, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 },
    /* 82 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 },
    /* 86 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 },
    /* 89 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 },
    /* 93 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 96 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 },
    /* 99 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 },
    /* 103 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 },
    /* 107 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 },
    /* 112 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_IMM_0, 0 },
    /* 116 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 },
    /* 119 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_2, 0 },
    /* 123 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_2, 0 },
    /* 126 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 130 */ { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 },
    /* 132 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_2, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_IMM_0, 0 },
    /* 136 */ { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 },
    /* 140 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 143 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 146 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 148 */ { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 150 */ { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 153 */ { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 156 */ { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 159 */ { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 163 */ { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 167 */ { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 170 */ { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 173 */ { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 175 */ { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 177 */ { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 181 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 185 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 187 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 192 */ { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 194 */ { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 196 */ { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 197 */ { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 201 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 205 */ { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 206 */ { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 209 */ { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 212 */ { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 214 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 217 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 },
    /* 222 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 224 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 228 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 229 */ { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 232 */ { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 235 */ { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 239 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 241 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 244 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 247 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 },
    /* 252 */ { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 },
    /* 257 */ { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 },
    /* 262 */ { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 },
    /* 267 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 },
    /* 272 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 276 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 280 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 283 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 286 */ { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 288 */ { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 291 */ { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 293 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 296 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 299 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 301 */ { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 304 */ { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 307 */ { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 309 */ { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 314 */ { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 318 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 323 */ { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 328 */ { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 331 */ { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 333 */ { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 335 */ { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 339 */ { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 342 */ { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 344 */ { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 347 */ { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 350 */ { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 352 */ { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 355 */ { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 },
    /* 358 */ { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
    /* 360 */ { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 },
    /* 363 */ { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 },
  }, {
    /* 0 */
    /* 0 */ TriCore_PSW,
    /* 1 */ TriCore_A10, TriCore_A11,
  }
};

#endif // GET_INSTRINFO_MC_DESC

#ifdef GET_COMPUTE_FEATURES
#undef GET_COMPUTE_FEATURES

#endif // GET_COMPUTE_FEATURES

#ifdef GET_AVAILABLE_OPCODE_CHECKER
#undef GET_AVAILABLE_OPCODE_CHECKER

#endif // GET_AVAILABLE_OPCODE_CHECKER

